@@ -14,14 +14,10 @@
 #ifndef __MTX_COMMON_CHAPTERS_H
 #define __MTX_COMMON_CHAPTERS_H
 
-#include "common/os.h"
-
-#include <string>
+#include "common/common_pch.h"
 
 #include <ebml/EbmlElement.h>
 
-#include "common/error.h"
-
 namespace libebml {
   class EbmlMaster;
 };
@@ -56,11 +52,11 @@ class mm_text_io_c;
 
 KaxChapters *
 parse_chapters(const std::string &file_name, int64_t min_tc = 0, int64_t max_tc = -1, int64_t offset = 0, const std::string &language = "", const std::string &charset = "",
-               bool exception_on_error = false, bool *is_simple_format = NULL, KaxTags **tags = NULL);
+               bool exception_on_error = false, bool *is_simple_format = nullptr, KaxTags **tags = nullptr);
 
 KaxChapters *
 parse_chapters(mm_text_io_c *io, int64_t min_tc = 0, int64_t max_tc = -1, int64_t offset = 0, const std::string &language = "", const std::string &charset = "",
-               bool exception_on_error = false, bool *is_simple_format = NULL, KaxTags **tags = NULL);
+               bool exception_on_error = false, bool *is_simple_format = nullptr, KaxTags **tags = nullptr);
 
 bool probe_xml_chapters(mm_text_io_c *in);
 KaxChapters *parse_xml_chapters(mm_text_io_c *in, int64_t min_tc, int64_t max_tc, int64_t offset, bool exception_on_error = false);
@@ -70,7 +66,7 @@ KaxChapters *parse_simple_chapters(mm_text_io_c *in, int64_t min_tc, int64_t max
 
 extern std::string g_cue_to_chapter_name_format;
 bool probe_cue_chapters(mm_text_io_c *in);
-KaxChapters *parse_cue_chapters(mm_text_io_c *in, int64_t min_tc, int64_t max_tc, int64_t offset, const std::string &language, const std::string &charset, KaxTags **tags = NULL);
+KaxChapters *parse_cue_chapters(mm_text_io_c *in, int64_t min_tc, int64_t max_tc, int64_t offset, const std::string &language, const std::string &charset, KaxTags **tags = nullptr);
 
 void write_chapters_xml(KaxChapters *chapters, mm_io_c *out);
 void write_chapters_simple(int &chapter_num, KaxChapters *chapters, mm_io_c *out);
