@@ -21,6 +21,7 @@
 #include <matroska/KaxVersion.h>
 #include <matroska/FileKax.h>
 
+#include "common/hacks.h"
 #include "common/mm_io.h"
 #include "common/random.h"
 #include "common/stereo_mode.h"
@@ -126,9 +127,10 @@ mtx_common_init() {
 
   atexit(mtx_common_cleanup);
 
-  srand(time(NULL));
+  srand(time(nullptr));
 
   init_debugging();
+  init_hacks();
 
   init_locales();
 
