@@ -18,9 +18,42 @@
 #undef max
 #undef __STRICT_ANSI__
 
-#include <boost/format.hpp>
-#include <boost/regex.hpp>
+#include <algorithm>
+#include <stdexcept>
 #include <string>
+#include <vector>
+
+#include <cassert>
+#include <cstring>
+
+#if defined(HAVE_SYS_TYPES_H)
+# include <sys/types.h>
+#endif // HAVE_SYS_TYPES_H
+#if defined(HAVE_STDINT_H)
+# include <stdint.h>
+#endif // HAVE_STDINT_H
+#if defined(HAVE_INTTYPES_H)
+# include <inttypes.h>
+#endif // HAVE_INTTYPES_H
+
+#include <boost/algorithm/string.hpp>
+#include <boost/bind.hpp>
+#include <boost/filesystem.hpp>
+#include <boost/format.hpp>
+#include <boost/function.hpp>
+#include <boost/logic/tribool.hpp>
+#include <boost/math/common_factor.hpp>
+#include <boost/range.hpp>
+#include <boost/range/algorithm_ext.hpp>
+#include <boost/range/algorithm.hpp>
+#include <boost/range/numeric.hpp>
+#include <boost/rational.hpp>
+#include <boost/regex.hpp>
+#include <boost/system/error_code.hpp>
+
+namespace ba  = boost::algorithm;
+namespace bfs = boost::filesystem;
+namespace br  = boost::range;
 
 #include "common/os.h"
 
@@ -45,9 +78,9 @@
 # endif
 #endif
 
+#include "common/smart_pointers.h"
 #include "common/debugging.h"
 #include "common/output.h"
-#include "common/smart_pointers.h"
 
 namespace libebml {
   class EbmlBinary;
