@@ -15,9 +15,7 @@
 #ifndef __MTX_COMMON_DIRAC_COMMON_H
 #define __MTX_COMMON_DIRAC_COMMON_H
 
-#include "common/os.h"
-
-#include "common/smart_pointers.h"
+#include "common/common_pch.h"
 
 #define DIRAC_SYNC_WORD            0x42424344 // 'BBCD'
 #define DIRAC_UNIT_SEQUENCE_HEADER 0x00
@@ -127,7 +125,7 @@ namespace dirac {
       if (m_seqhdr_found)
         return memory_cptr(m_raw_seqhdr->clone());
       else
-        return memory_cptr(NULL);
+        return memory_cptr(nullptr);
     }
 
     virtual void handle_unit(memory_cptr packet);
