@@ -15,9 +15,9 @@
 #ifndef __MTX_COMMON_MPEG4_P10_H
 #define __MTX_COMMON_MPEG4_P10_H
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
-#include "common/memory.h"
+#include "common/math.h"
 
 #define NALU_START_CODE 0x00000001
 
@@ -56,6 +56,7 @@ namespace mpeg4 {
       unsigned int profile_idc;
       unsigned int profile_compat;
       unsigned int level_idc;
+      unsigned int chroma_format_idc;
       unsigned int log2_max_frame_num;
       unsigned int pic_order_cnt_type;
       unsigned int log2_max_pic_order_cnt_lsb;
@@ -84,6 +85,9 @@ namespace mpeg4 {
       }
 
       void dump();
+
+      bool timing_info_valid() const;
+      int64_t default_duration() const;
     };
 
     struct pps_info_t {
@@ -118,10 +122,13 @@ namespace mpeg4 {
       unsigned int pps;
 
       slice_info_t() {
-        memset(this, 0, sizeof(*this));
+        clear();
       }
 
-      void dump();
+      void dump() const;
+      void clear() {
+        memset(this, 0, sizeof(*this));
+      }
     };
 
     void nalu_to_rbsp(memory_cptr &buffer);
@@ -137,39 +144,31 @@ namespace mpeg4 {
     struct avc_frame_t {
       memory_cptr m_data;
       int64_t m_start, m_end, m_ref1, m_ref2;
-      bool m_keyframe;
+      bool m_keyframe, m_has_provided_timecode;
       slice_info_t m_si;
+      int m_presentation_order, m_decode_order;
 
       avc_frame_t() {
         clear();
-      };
+      }
 
       avc_frame_t(const avc_frame_t &f) {
         *this = f;
-      };
-
-      avc_frame_t &operator =(const avc_frame_t &f) {
-        m_data     = f.m_data;
-        m_start    = f.m_start;
-        m_end      = f.m_end;
-        m_ref1     = f.m_ref1;
-        m_ref2     = f.m_ref2;
-        m_keyframe = f.m_keyframe;
-        m_si       = f.m_si;
-
-        return *this;
-      };
+      }
 
       void clear() {
-        m_start    = 0;
-        m_end      = 0;
-        m_ref1     = 0;
-        m_ref2     = 0;
-        m_keyframe = false;
-        m_data     = memory_cptr(NULL);
+        m_start                 = 0;
+        m_end                   = 0;
+        m_ref1                  = 0;
+        m_ref2                  = 0;
+        m_keyframe              = false;
+        m_has_provided_timecode = false;
+        m_presentation_order    = 0;
+        m_decode_order          = 0;
+        m_data.clear();
 
-        memset(&m_si, 0, sizeof(m_si));
-      };
+        m_si.clear();
+      }
     };
 
     class nalu_size_length_x: public mtx::exception {
@@ -203,21 +202,25 @@ namespace mpeg4 {
       bool m_keep_ar_info;
       bool m_avcc_ready, m_avcc_changed;
 
-      int64_t m_default_duration;
+      int64_t m_stream_default_duration, m_forced_default_duration, m_container_default_duration;
       int m_frame_number, m_num_skipped_frames;
       bool m_first_keyframe_found, m_recovery_point_valid, m_b_frames_since_keyframe;
 
-      std::deque<avc_frame_t> m_frames, m_frames_out;
-      std::deque<int64_t> m_timecodes;
-      int64_t m_max_timecode;
+      bool m_par_found;
+      int64_rational_c m_par;
 
-      bool m_generate_timecodes;
+      std::deque<avc_frame_t> m_frames, m_frames_out;
+      std::deque<int64_t> m_provided_timecodes;
+      std::deque<uint64_t> m_provided_stream_positions;
+      int64_t m_max_timecode;
+      std::map<int64_t, int64_t> m_duration_frequency;
 
       std::deque<memory_cptr> m_sps_list, m_pps_list, m_extra_data;
       std::vector<sps_info_t> m_sps_info_list;
       std::vector<pps_info_t> m_pps_info_list;
 
       memory_cptr m_unparsed_buffer;
+      uint64_t m_stream_position, m_parsed_position;
 
       avc_frame_t m_incomplete_frame;
       bool m_have_incomplete_frame;
@@ -225,37 +228,52 @@ namespace mpeg4 {
 
       bool m_ignore_nalu_size_length_errors, m_discard_actual_frames;
 
-      std::vector<int> m_num_slices_by_type;
-      bool m_debug_keyframe_detection, m_debug_nalu_types;
+      bool m_debug_keyframe_detection, m_debug_nalu_types, m_debug_timecode_statistics, m_debug_timecodes, m_debug_sps_info;
       std::map<int, std::string> m_nalu_names_by_type;
 
+      struct stats_t {
+        std::vector<int> num_slices_by_type;
+        size_t num_frames_out, num_frames_discarded, num_timecodes_in, num_timecodes_generated, num_timecodes_discarded, num_field_slices, num_frame_slices;
+
+        stats_t()
+          : num_slices_by_type(11, 0)
+          , num_frames_out(0)
+          , num_frames_discarded(0)
+          , num_timecodes_in(0)
+          , num_timecodes_generated(0)
+          , num_timecodes_discarded(0)
+          , num_field_slices(0)
+          , num_frame_slices(0)
+        {
+        }
+      } m_stats;
+
     public:
       avc_es_parser_c();
       ~avc_es_parser_c();
 
-      void set_default_duration(int64_t default_duration) {
-        m_default_duration = default_duration;
+      void force_default_duration(int64_t default_duration) {
+        m_forced_default_duration = default_duration;
       }
 
-      void enable_timecode_generation(int64_t default_duration) {
-        m_default_duration   = default_duration;
-        m_generate_timecodes = true;
-      };
+      void set_container_default_duration(int64_t default_duration) {
+        m_container_default_duration = default_duration;
+      }
 
       void set_keep_ar_info(bool keep) {
         m_keep_ar_info = keep;
-      };
+      }
 
-      void add_bytes(unsigned char *buf, int size);
+      void add_bytes(unsigned char *buf, size_t size);
       void add_bytes(memory_cptr &buf) {
         add_bytes(buf->get_buffer(), buf->get_size());
-      };
+      }
 
       void flush();
 
       bool frame_available() {
         return !m_frames_out.empty();
-      };
+      }
 
       avc_frame_t get_frame() {
         assert(!m_frames_out.empty());
@@ -264,53 +282,71 @@ namespace mpeg4 {
         m_frames_out.erase(m_frames_out.begin(), m_frames_out.begin() + 1);
 
         return frame;
-      };
+      }
 
-      memory_cptr get_avcc();
+      memory_cptr get_avcc() const;
 
-      bool avcc_changed() {
+      bool avcc_changed() const {
         return m_avcc_changed;
-      };
+      }
 
-      int get_width() {
+      int get_width() const {
         assert(!m_sps_info_list.empty());
         return m_sps_info_list.begin()->width;
-      };
+      }
 
-      int get_height() {
+      int get_height() const {
         assert(!m_sps_info_list.empty());
         return m_sps_info_list.begin()->height;
-      };
+      }
 
       void handle_nalu(memory_cptr nalu);
 
       void add_timecode(int64_t timecode);
 
-      bool headers_parsed() {
+      bool headers_parsed() const {
         return m_avcc_ready;
-      };
+      }
 
       void set_nalu_size_length(int nalu_size_length) {
         m_nalu_size_length = nalu_size_length;
-      };
+      }
 
-      int get_nalu_size_length() {
+      int get_nalu_size_length() const {
         return m_nalu_size_length;
-      };
+      }
 
       void ignore_nalu_size_length_errors() {
         m_ignore_nalu_size_length_errors = true;
-      };
+      }
 
       void discard_actual_frames(bool discard = true);
 
-      int get_num_skipped_frames() {
+      int get_num_skipped_frames() const {
         return m_num_skipped_frames;
-      };
+      }
 
-      void dump_info();
+      void dump_info() const;
 
-      std::string get_nalu_type_name(int type);
+      std::string get_nalu_type_name(int type) const;
+
+      bool has_stream_default_duration() const {
+        return -1 != m_stream_default_duration;
+      }
+      int64_t get_stream_default_duration() const {
+        assert(-1 != m_stream_default_duration);
+        return m_stream_default_duration;
+      }
+
+      int64_t duration_for(slice_info_t const &si) const;
+      int64_t get_most_often_used_duration() const;
+
+      size_t get_num_field_slices() const;
+      size_t get_num_frame_slices() const;
+
+      bool has_par_been_found() const;
+      int64_rational_c const &get_par() const;
+      std::pair<int64_t, int64_t> const get_display_dimensions(int width = -1, int height = -1) const;
 
     protected:
       bool parse_slice(memory_cptr &buffer, slice_info_t &si);
@@ -319,14 +355,12 @@ namespace mpeg4 {
       void handle_sei_nalu(memory_cptr &nalu);
       void handle_slice_nalu(memory_cptr &nalu);
       void cleanup();
-      void default_cleanup();
       bool flush_decision(slice_info_t &si, slice_info_t &ref);
       void flush_incomplete_frame();
       void flush_unhandled_nalus();
-      void write_nalu_size(unsigned char *buffer, size_t size, int this_nalu_size_length = -1);
+      void write_nalu_size(unsigned char *buffer, size_t size, int this_nalu_size_length = -1) const;
       memory_cptr create_nalu_with_size(const memory_cptr &src, bool add_extra_data = false);
       void init_nalu_names();
-      void create_missing_timecodes();
     };
     typedef counted_ptr<avc_es_parser_c> avc_es_parser_cptr;
   };
