@@ -14,9 +14,6 @@
 
 #include "common/common_pch.h"
 
-#include <boost/range/numeric.hpp>
-#include <string.h>
-
 #include "common/bit_cursor.h"
 #include "common/endian.h"
 #include "common/strings/formatting.h"
@@ -50,7 +47,7 @@ vc1::frame_t::frame_t()
 void
 vc1::frame_t::init() {
   header.init();
-  data                     = memory_cptr(NULL);
+  data                     = memory_cptr(nullptr);
   timecode                 = -1;
   duration                 = 0;
   contains_sequence_header = false;
@@ -343,7 +340,7 @@ vc1::es_parser_c::add_bytes(unsigned char *buffer,
     m_unparsed_buffer = new_unparsed_buffer;
 
   } else
-    m_unparsed_buffer = memory_cptr(NULL);
+    m_unparsed_buffer = memory_cptr(nullptr);
 }
 
 void
@@ -351,10 +348,10 @@ vc1::es_parser_c::flush() {
   if (m_unparsed_buffer.is_set() && (4 <= m_unparsed_buffer->get_size())) {
     uint32_t marker = get_uint32_be(m_unparsed_buffer->get_buffer());
     if (vc1::is_marker(marker))
-      handle_packet(clone_memory(m_unparsed_buffer->get_buffer(), m_unparsed_buffer->get_size()));
+      handle_packet(memory_c::clone(m_unparsed_buffer->get_buffer(), m_unparsed_buffer->get_size()));
   }
 
-  m_unparsed_buffer = memory_cptr(NULL);
+  m_unparsed_buffer = memory_cptr(nullptr);
 
   flush_frame();
 }
@@ -400,7 +397,8 @@ vc1::es_parser_c::handle_end_of_sequence_packet(memory_cptr) {
 
 void
 vc1::es_parser_c::handle_entrypoint_packet(memory_cptr packet) {
-  add_pre_frame_extra_data(packet);
+  if (!postpone_processing(packet))
+    add_pre_frame_extra_data(packet);
 
   if (!m_raw_entrypoint.is_set())
     m_raw_entrypoint = memory_cptr(packet->clone());
@@ -408,15 +406,21 @@ vc1::es_parser_c::handle_entrypoint_packet(memory_cptr packet) {
 
 void
 vc1::es_parser_c::handle_field_packet(memory_cptr packet) {
+  if (postpone_processing(packet))
+    return;
+
   add_post_frame_extra_data(packet);
 }
 
 void
 vc1::es_parser_c::handle_frame_packet(memory_cptr packet) {
+  if (postpone_processing(packet))
+    return;
+
   flush_frame();
 
   vc1::frame_header_t frame_header;
-  if (!m_seqhdr_found || !vc1::parse_frame_header(packet->get_buffer(), packet->get_size(), frame_header, m_seqhdr))
+  if (!vc1::parse_frame_header(packet->get_buffer(), packet->get_size(), frame_header, m_seqhdr))
     return;
 
   m_current_frame        = frame_cptr(new frame_t);
@@ -450,16 +454,24 @@ vc1::es_parser_c::handle_sequence_header_packet(memory_cptr packet) {
 
   if (!m_default_duration_forced && m_seqhdr.framerate_flag && (0 != m_seqhdr.framerate_num) && (0 != m_seqhdr.framerate_den))
     m_default_duration = 1000000000ll * m_seqhdr.framerate_num / m_seqhdr.framerate_den;
+
+  process_unparsed_packets();
 }
 
 void
 vc1::es_parser_c::handle_slice_packet(memory_cptr packet) {
+  if (postpone_processing(packet))
+    return;
+
   add_post_frame_extra_data(packet);
 }
 
 void
 vc1::es_parser_c::handle_unknown_packet(uint32_t,
                                         memory_cptr packet) {
+  if (postpone_processing(packet))
+    return;
+
   add_post_frame_extra_data(packet);
 }
 
@@ -476,7 +488,25 @@ vc1::es_parser_c::flush_frame() {
 
   m_frames.push_back(m_current_frame);
 
-  m_current_frame = frame_cptr(NULL);
+  m_current_frame = frame_cptr(nullptr);
+}
+
+bool
+vc1::es_parser_c::postpone_processing(memory_cptr &packet) {
+  if (m_seqhdr_found)
+    return false;
+
+  packet->grab();
+  m_unparsed_packets.push_back(packet);
+  return true;
+}
+
+void
+vc1::es_parser_c::process_unparsed_packets() {
+  for (auto &packet : m_unparsed_packets)
+    handle_frame_packet(packet);
+
+  m_unparsed_packets.clear();
 }
 
 void
