@@ -15,12 +15,10 @@
 #ifndef __MTX_COMMON_VC1_COMMON_H
 #define __MTX_COMMON_VC1_COMMON_H
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
 #include <deque>
 
-#include "common/smart_pointers.h"
-
 #define VC1_PROFILE_SIMPLE    0x00000000
 #define VC1_PROFILE_MAIN      0x00000001
 #define VC1_PROFILE_COMPLEX   0x00000002
@@ -157,6 +155,8 @@ namespace vc1 {
     std::deque<frame_cptr> m_frames;
     frame_cptr m_current_frame;
 
+    std::deque<memory_cptr> m_unparsed_packets;
+
     std::deque<int64_t> m_timecodes;
     std::deque<int64_t> m_timecode_positions;
     int64_t m_previous_timecode;
@@ -198,11 +198,11 @@ namespace vc1 {
       if (m_seqhdr_found)
         return memory_cptr(m_raw_seqhdr->clone());
       else
-        return memory_cptr(NULL);
+        return memory_cptr(nullptr);
     }
 
     virtual memory_cptr get_raw_entrypoint() {
-      return memory_cptr(m_raw_entrypoint.is_set() ? m_raw_entrypoint->clone() : NULL);
+      return m_raw_entrypoint.is_set() ? m_raw_entrypoint->clone() : memory_cptr(nullptr);
     }
 
     virtual void handle_packet(memory_cptr packet);
@@ -249,6 +249,9 @@ namespace vc1 {
     virtual void add_post_frame_extra_data(memory_cptr packet);
     virtual void combine_extra_data_with_packet();
 
+    virtual bool postpone_processing(memory_cptr &packet);
+    virtual void process_unparsed_packets();
+
     virtual void flush_frame();
 
     virtual bool is_timecode_available();
