@@ -13,10 +13,7 @@
 #ifndef __MTX_COMMON_WXCOMMON_H
 #define __MTX_COMMON_WXCOMMON_H
 
-#include "common/os.h"
-
-#include <boost/format.hpp>
-#include <string>
+#include "common/common_pch.h"
 
 #include <ebml/EbmlString.h>
 
@@ -55,7 +52,7 @@ wxU(const EbmlString &s) {
 
 inline wxString
 wxU(EbmlString *s) {
-  if (NULL == s)
+  if (nullptr == s)
     return wxEmptyString;
   return wxU(static_cast<const std::string &>(*s));
 }
