@@ -42,7 +42,7 @@ struct attachment_t {
   attachment_t()
     : size(-1)
     , id(-1)
-    , fdata(NULL)
+    , fdata(nullptr)
     , valid(false)
   {
   };
@@ -92,7 +92,7 @@ handle_attachments(KaxAttachments *atts,
   size_t i;
   for (i = 0; atts->ListSize() > i; ++i) {
     KaxAttached *att = dynamic_cast<KaxAttached *>((*atts)[i]);
-    assert(NULL != att);
+    assert(nullptr != att);
 
     attachment_t attachment = attachment_t::parse_new(*att);
     if (!attachment.valid)
