@@ -13,11 +13,6 @@
 
 #include "common/common_pch.h"
 
-#include <algorithm>
-#include <boost/bind.hpp>
-#include <stdexcept>
-#include <typeinfo>
-
 #include "common/ebml.h"
 #include "common/strings/formatting.h"
 #include "common/strings/parsing.h"
@@ -203,11 +198,11 @@ extract_cli_parser_c::set_extraction_mode() {
     { "chapters",     options_c::em_chapters     },
     { "cuesheet",     options_c::em_cuesheet     },
     { "timecodes_v2", options_c::em_timecodes_v2 },
-    { NULL,           options_c::em_unknown      },
+    { nullptr,           options_c::em_unknown      },
   };
 
   int i;
-  for (i = 0; NULL != s_mode_map[i].name; ++i)
+  for (i = 0; nullptr != s_mode_map[i].name; ++i)
     if (m_current_arg == s_mode_map[i].name) {
       m_options.m_extraction_mode = s_mode_map[i].extraction_mode;
       return;
