@@ -57,7 +57,7 @@ show_element(EbmlElement *l,
   level_buffer[level] = 0;
 
   mxinfo(boost::format("(%1%) %2%+ %3%") % NAME % level_buffer % info);
-  if (NULL != l)
+  if (nullptr != l)
     mxinfo(boost::format(Y(" at %1%")) % l->GetElementPosition());
   mxinfo("\n");
 }
