@@ -31,10 +31,8 @@ xtr_mpeg1_2_video_c::create_file(xtr_base_c *master,
   xtr_base_c::create_file(master, track);
 
   KaxCodecPrivate *priv = FINDFIRST(&track, KaxCodecPrivate);
-  if (NULL != priv) {
-    memory_cptr mpriv   = decode_codec_private(priv);
-    m_seq_hdr           = clone_memory(mpriv);
-  }
+  if (nullptr != priv)
+    m_seq_hdr = decode_codec_private(priv);
 }
 
 void
@@ -75,7 +73,7 @@ xtr_mpeg1_2_video_c::handle_frame(memory_cptr &frame,
         size_t seq_size = end_pos - (((end_pos + 1) < size) ? 3 : 4);
 
         if ((m_seq_hdr->get_size() != seq_size) || memcmp(m_seq_hdr->get_buffer(), buf, seq_size))
-          m_seq_hdr = clone_memory(buf, seq_size);
+          m_seq_hdr = memory_c::clone(buf, seq_size);
       }
     }
 
@@ -89,5 +87,5 @@ xtr_mpeg1_2_video_c::handle_frame(memory_cptr &frame,
 void
 xtr_mpeg1_2_video_c::handle_codec_state(memory_cptr &codec_state) {
   m_content_decoder.reverse(codec_state, CONTENT_ENCODING_SCOPE_CODECPRIVATE);
-  m_seq_hdr = clone_memory(codec_state);
+  m_seq_hdr = codec_state->clone();
 }
