@@ -83,7 +83,7 @@ xtr_srt_c::handle_frame(memory_cptr &frame,
 const char *xtr_ssa_c::ms_kax_ssa_fields[10] = {
   "readorder", "layer",   "style",   "name",
   "marginl",   "marginr", "marginv",
-  "effect",    "text",    NULL
+  "effect",    "text",    nullptr
 };
 
 xtr_ssa_c::xtr_ssa_c(const std::string &codec_id,
@@ -100,7 +100,7 @@ void
 xtr_ssa_c::create_file(xtr_base_c *master,
                        KaxTrackEntry &track) {
   KaxCodecPrivate *priv = FINDFIRST(&track, KaxCodecPrivate);
-  if (NULL == priv)
+  if (nullptr == priv)
     mxerror(boost::format(Y("Track %1% with the CodecID '%2%' is missing the \"codec private \" element and cannot be extracted.\n")) % m_tid % m_codec_id);
 
   xtr_base_c::create_file(master, track);
@@ -126,7 +126,7 @@ xtr_ssa_c::create_file(xtr_base_c *master,
   delete []s;
 
   const char *p1;
-  if (((p1 = strstr(sconv.c_str(), "[Events]")) == NULL) || (strstr(p1, "Format:") == NULL)) {
+  if (((p1 = strstr(sconv.c_str(), "[Events]")) == nullptr) || (strstr(p1, "Format:") == nullptr)) {
     if (m_codec_id == MKV_S_TEXTSSA)
       sconv += "\n[Events]\nFormat: Marked, Start, End, Style, Name, MarginL, MarginR, MarginV, Effect, Text\n";
     else
@@ -244,7 +244,7 @@ xtr_ssa_c::handle_frame(memory_cptr &frame,
 
     else {
       int k;
-      for (k = 0; NULL != ms_kax_ssa_fields[k]; ++k)
+      for (k = 0; nullptr != ms_kax_ssa_fields[k]; ++k)
         if (format == ms_kax_ssa_fields[k]) {
           line += fields[k];
           break;
@@ -287,7 +287,7 @@ void
 xtr_usf_c::create_file(xtr_base_c *master,
                        KaxTrackEntry &track) {
   KaxCodecPrivate *priv = FINDFIRST(&track, KaxCodecPrivate);
-  if (NULL == priv)
+  if (nullptr == priv)
     mxerror(boost::format(Y("Track %1% with the CodecID '%2%' is missing the \"codec private\" element and cannot be extracted.\n")) % m_tid % m_codec_id);
 
   init_content_decoder(track);
@@ -296,14 +296,14 @@ xtr_usf_c::create_file(xtr_base_c *master,
   m_codec_private.append((const char *)new_priv->get_buffer(), new_priv->get_size());
 
   KaxTrackLanguage *language = FINDFIRST(&track, KaxTrackLanguage);
-  if (NULL == language)
+  if (nullptr == language)
     m_language = "eng";
   else
     m_language = std::string(*language);
 
-  if (NULL != master) {
+  if (nullptr != master) {
     xtr_usf_c *usf_master = dynamic_cast<xtr_usf_c *>(master);
-    if (NULL == usf_master)
+    if (nullptr == usf_master)
       mxerror(boost::format(Y("Cannot write track %1% with the CodecID '%2%' to the file '%3%' because "
                               "track %4% with the CodecID '%5%' is already being written to the same file.\n"))
               % m_tid % m_codec_id % m_file_name % master->m_tid % master->m_codec_id);
@@ -381,7 +381,7 @@ xtr_usf_c::finish_track() {
 void
 xtr_usf_c::finish_file() {
   try {
-    if (NULL == m_master) {
+    if (nullptr == m_master) {
       m_formatter->format("</USFSubtitles>");
       m_out->puts("\n");
     }
