@@ -13,11 +13,6 @@
 
 #include "common/common_pch.h"
 
-#include <algorithm>
-#include <boost/bind.hpp>
-#include <stdexcept>
-#include <typeinfo>
-
 #include "common/ebml.h"
 #include "common/strings/formatting.h"
 #include "common/strings/parsing.h"
