@@ -13,7 +13,7 @@
 #ifndef __RIGHTCLICK_TREE_WIDGET_H
 #define __RIGHTCLICK_TREE_WIDGET_H
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
 #include <QTreeWidget>
 
@@ -23,7 +23,7 @@ class rightclick_tree_widget: public QTreeWidget {
 public slots:
 
 public:
-  rightclick_tree_widget(QWidget *parent = NULL);
+  rightclick_tree_widget(QWidget *parent = nullptr);
 
 protected:
   virtual void mousePressEvent(QMouseEvent *event);
