@@ -17,8 +17,6 @@
 
 #include "common/common_pch.h"
 
-#include <boost/logic/tribool.hpp>
-
 #include "common/compression.h"
 #include "common/error.h"
 #include "common/kax_file.h"
@@ -68,7 +66,7 @@ struct kax_track_t {
   unsigned char *headers[3];
   uint32_t header_sizes[3];
 
-  boost::logic::tribool default_track, forced_track;
+  boost::logic::tribool default_track, forced_track, enabled_track;
   std::string language;
 
   int64_t units_processed;
@@ -121,17 +119,18 @@ struct kax_track_t {
     , a_formattag(0)
     , a_sfreq(8000.0)
     , a_osfreq(0.0)
-    , private_data(NULL)
+    , private_data(nullptr)
     , private_size(0)
     , default_track(true)
     , forced_track(boost::logic::indeterminate)
+    , enabled_track(true)
     , language("eng")
     , units_processed(0)
     , ok(false)
     , previous_timecode(0)
-    , tags(NULL)
+    , tags(nullptr)
     , ptzr(-1)
-    , ptzr_ptr(NULL)
+    , ptzr_ptr(nullptr)
     , headers_set(false)
     , ignore_duration_hack(false)
   {
@@ -142,7 +141,7 @@ struct kax_track_t {
 
   ~kax_track_t() {
     safefree(private_data);
-    if (NULL != tags)
+    if (nullptr != tags)
       delete tags;
   }
 
@@ -214,8 +213,8 @@ protected:
   virtual void init_passthrough_packetizer(kax_track_t *t);
   virtual void set_packetizer_headers(kax_track_t *t);
   virtual void read_first_frames(kax_track_t *t, unsigned num_wanted = 1);
-  virtual kax_track_t *find_track_by_num(uint64_t num, kax_track_t *c = NULL);
-  virtual kax_track_t *find_track_by_uid(uint64_t uid, kax_track_t *c = NULL);
+  virtual kax_track_t *find_track_by_num(uint64_t num, kax_track_t *c = nullptr);
+  virtual kax_track_t *find_track_by_uid(uint64_t uid, kax_track_t *c = nullptr);
 
   virtual bool verify_acm_audio_track(kax_track_t *t);
   virtual bool verify_flac_audio_track(kax_track_t *t);
@@ -270,8 +269,6 @@ protected:
   virtual void process_simple_block(KaxCluster *cluster, KaxSimpleBlock *block_simple);
   virtual void process_block_group(KaxCluster *cluster, KaxBlockGroup *block_group);
 
-  virtual mpeg4::p10::avc_es_parser_cptr parse_first_mpeg4_p10_frame(kax_track_t *t, track_info_c &nti);
-
   void init_l1_position_storage(deferred_positions_t &storage);
   virtual bool has_deferred_element_been_processed(deferred_l1_type_e type, int64_t position);
 };
