@@ -23,8 +23,6 @@
 #include "merge/packet_extensions.h"
 #include "merge/pr_generic.h"
 
-namespace bfs = boost::filesystem;
-
 struct mpeg_ps_id_t {
   int id;
   int sub_id;
@@ -80,13 +78,13 @@ struct mpeg_ps_track_t {
     v_dheight(0),
     v_frame_rate(0),
     v_aspect_ratio(0),
-    raw_seq_hdr(NULL),
+    raw_seq_hdr(nullptr),
     raw_seq_hdr_size(0),
     a_channels(0),
     a_sample_rate(0),
     a_bits_per_sample(0),
     a_bsid(0),
-    buffer(NULL),
+    buffer(nullptr),
     buffer_usage(0),
     buffer_size(0),
     multiple_timecodes_packet_extension(new multiple_timecodes_packet_extension_c)
