@@ -12,10 +12,10 @@
    and Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include <iostream>
-
 #include "common/common_pch.h"
 
+#include <iostream>
+
 #include "common/checksums.h"
 #include "common/clpi.h"
 #include "common/endian.h"
@@ -38,8 +38,6 @@
 #include "output/p_truehd.h"
 #include "output/p_vc1.h"
 
-namespace bfs = boost::filesystem;
-
 #define TS_CONSECUTIVE_PACKETS 16
 #define TS_PROBE_SIZE          (2 * TS_CONSECUTIVE_PACKETS * 204)
 #define TS_PIDS_DETECT_SIZE    10 * 1024 * 1024
@@ -64,7 +62,7 @@ mpeg_ts_track_c::send_to_packetizer() {
              % pid % pes_payload_size % pes_payload->get_size() % format_timecode(timecode_to_use) % (-1 == m_previous_timecode ? std::string("-1") : format_timecode(m_previous_timecode)));
 
   if (ptzr != -1)
-    reader.m_reader_packetizers[ptzr]->process(new packet_t(clone_memory(pes_payload->get_buffer(), pes_payload->get_size()), timecode_to_use));
+    reader.m_reader_packetizers[ptzr]->process(new packet_t(memory_c::clone(pes_payload->get_buffer(), pes_payload->get_size()), timecode_to_use));
 
   pes_payload->remove(pes_payload->get_size());
   processed                          = false;
@@ -133,9 +131,9 @@ mpeg_ts_track_c::new_stream_v_mpeg_1_2() {
   v_dheight  = v_height;
 
   MPEGChunk *raw_seq_hdr_chunk = m_m2v_parser->GetRealSequenceHeader();
-  if (NULL != raw_seq_hdr_chunk) {
+  if (nullptr != raw_seq_hdr_chunk) {
     mxverb(3, boost::format("new_stream_v_mpeg_1_2: sequence header size: %1%\n") % raw_seq_hdr_chunk->GetSize());
-    raw_seq_hdr = clone_memory(raw_seq_hdr_chunk->GetPointer(), raw_seq_hdr_chunk->GetSize());
+    raw_seq_hdr = memory_c::clone(raw_seq_hdr_chunk->GetPointer(), raw_seq_hdr_chunk->GetSize());
   }
 
   mxverb(3, boost::format("new_stream_v_mpeg_1_2: width: %1%, height: %2%\n") % v_width % v_height);
@@ -164,77 +162,14 @@ mpeg_ts_track_c::new_stream_v_avc() {
   if (!m_avc_parser->headers_parsed())
     return FILE_STATUS_MOREDATA;
 
-  v_avcc = m_avc_parser->get_avcc();
+  fourcc   = FOURCC('A', 'V', 'C', '1');
+  v_width  = m_avc_parser->get_width();
+  v_height = m_avc_parser->get_height();
 
-  try {
-    mm_mem_io_c avcc(v_avcc->get_buffer(), v_avcc->get_size());
-    mm_mem_io_c new_avcc(NULL, v_avcc->get_size(), 1024);
-    memory_cptr nalu(new memory_c());
-    int num_sps, sps, sps_length;
-    sps_info_t sps_info;
-
-    avcc.read(nalu, 5);
-    new_avcc.write(nalu);
-
-    num_sps = avcc.read_uint8();
-    new_avcc.write_uint8(num_sps);
-    num_sps &= 0x1f;
-
-    for (sps = 0; sps < num_sps; sps++) {
-      bool abort;
-
-      sps_length = avcc.read_uint16_be();
-      if ((sps_length + avcc.getFilePointer()) >= v_avcc->get_size())
-        sps_length = v_avcc->get_size() - avcc.getFilePointer();
-      avcc.read(nalu, sps_length);
-
-      abort = false;
-      if ((0 < sps_length) && ((nalu->get_buffer()[0] & 0x1f) == 7)) {
-        nalu_to_rbsp(nalu);
-        if (!mpeg4::p10::parse_sps(nalu, sps_info, true))
-          throw false;
-        rbsp_to_nalu(nalu);
-        abort = true;
-      }
-
-      new_avcc.write_uint16_be(nalu->get_size());
-      new_avcc.write(nalu);
-
-      if (abort) {
-        avcc.read(nalu, v_avcc->get_size() - avcc.getFilePointer());
-        new_avcc.write(nalu);
-        break;
-      }
-    }
-
-    fourcc   = FOURCC('A', 'V', 'C', '1');
-    v_avcc   = memory_cptr(new memory_c(new_avcc.get_and_lock_buffer(), new_avcc.getFilePointer(), true));
-    v_width  = sps_info.width;
-    v_height = sps_info.height;
-
-    mxverb(3, boost::format("new_stream_v_avc: timing_info_present %1%, num_units_in_tick %2%, time_scale %3%, fixed_frame_rate %4%\n")
-           % sps_info.timing_info_present % sps_info.num_units_in_tick % sps_info.time_scale % sps_info.fixed_frame_rate);
-
-    if (sps_info.timing_info_present && sps_info.num_units_in_tick)
-      v_frame_rate = static_cast<float>(sps_info.time_scale) / sps_info.num_units_in_tick;
-
-    if (sps_info.ar_found) {
-      float aspect_ratio = (float)sps_info.width / (float)sps_info.height * (float)sps_info.par_num / (float)sps_info.par_den;
-      v_aspect_ratio = aspect_ratio;
-
-      if (aspect_ratio > ((float)v_width / (float)v_height)) {
-        v_dwidth  = irnd(v_height * aspect_ratio);
-        v_dheight = v_height;
-
-      } else {
-        v_dwidth  = v_width;
-        v_dheight = irnd(v_width / aspect_ratio);
-      }
-    }
-    mxverb(3, boost::format("new_stream_v_avc: width: %1%, height: %2%\n") % v_width % v_height);
-
-  } catch (...) {
-    throw false;
+  if (m_avc_parser->has_par_been_found()) {
+    auto dimensions = m_avc_parser->get_display_dimensions();
+    v_dwidth        = dimensions.first;
+    v_dheight       = dimensions.second;
   }
 
   return 0;
@@ -283,18 +218,20 @@ int
 mpeg_ts_track_c::new_stream_a_ac3() {
   add_pes_payload_to_probe_data();
 
-  ac3_header_t header;
-
-  if (-1 == find_ac3_header(m_probe_data->get_buffer(), m_probe_data->get_size(), &header, false))
+  ac3::parser_c parser;
+  parser.add_bytes(m_probe_data->get_buffer(), m_probe_data->get_size());
+  if (!parser.frame_available())
     return FILE_STATUS_MOREDATA;
 
+  ac3::frame_c header = parser.get_frame();
+
   mxverb(2,
          boost::format("first ac3 header bsid %1% channels %2% sample_rate %3% bytes %4% samples %5%\n")
-         % header.bsid % header.channels % header.sample_rate % header.bytes % header.samples);
+         % header.m_bs_id % header.m_channels % header.m_sample_rate % header.m_bytes % header.m_samples);
 
-  a_channels    = header.channels;
-  a_sample_rate = header.sample_rate;
-  a_bsid        = header.bsid;
+  a_channels    = header.m_channels;
+  a_sample_rate = header.m_sample_rate;
+  a_bsid        = header.m_bs_id;
 
   return 0;
 }
@@ -496,7 +433,7 @@ mpeg_ts_reader_c::identify() {
                        : FOURCC('P', 'G', 'S', ' ') == track->fourcc ? "HDMV PGS"
                        // : FOURCC('P', 'C', 'M', ' ') == track->fourcc ? "PCM"
                        // : FOURCC('L', 'P', 'C', 'M') == track->fourcc ? "LPCM"
-                       :                                               NULL;
+                       :                                               nullptr;
 
     if (!fourcc)
       continue;
@@ -517,7 +454,7 @@ mpeg_ts_reader_c::identify() {
 
 int
 mpeg_ts_reader_c::parse_pat(unsigned char *pat) {
-  if (pat == NULL) {
+  if (pat == nullptr) {
     mxdebug_if(m_debug_pat_pmt, "mpeg_ts:parse_pat: Invalid parameters!\n");
     return -1;
   }
@@ -597,7 +534,7 @@ mpeg_ts_reader_c::parse_pat(unsigned char *pat) {
 
 int
 mpeg_ts_reader_c::parse_pmt(unsigned char *pmt) {
-  if (pmt == NULL) {
+  if (pmt == nullptr) {
     mxdebug_if(m_debug_pat_pmt, "mpeg_ts:parse_pmt: Invalid parameters!\n");
     return -1;
   }
@@ -1121,7 +1058,7 @@ mpeg_ts_reader_c::create_mpeg1_2_video_packetizer(mpeg_ts_track_ptr &track) {
     m_ti.m_private_data = track->raw_seq_hdr->get_buffer();
     m_ti.m_private_size = track->raw_seq_hdr->get_size();
   } else {
-    m_ti.m_private_data = NULL;
+    m_ti.m_private_data = nullptr;
     m_ti.m_private_size = 0;
   }
 
@@ -1129,25 +1066,18 @@ mpeg_ts_reader_c::create_mpeg1_2_video_packetizer(mpeg_ts_track_ptr &track) {
                                                                        track->v_dwidth, track->v_dheight, false);
   track->ptzr                         = add_packetizer(m2vpacketizer);
   show_packetizer_info(m_ti.m_id, PTZR(track->ptzr));
-  m_ti.m_private_data                 = NULL;
+  m_ti.m_private_data                 = nullptr;
   m_ti.m_private_size                 = 0;
   m2vpacketizer->set_video_interlaced_flag(track->v_interlaced);
 }
 
 void
 mpeg_ts_reader_c::create_mpeg4_p10_es_video_packetizer(mpeg_ts_track_ptr &track) {
+  generic_packetizer_c *ptzr = new mpeg4_p10_es_video_packetizer_c(this, m_ti);
+  track->ptzr                = add_packetizer(ptzr);
+  ptzr->set_video_pixel_dimensions(track->v_width, track->v_height);
 
-  mpeg4_p10_es_video_packetizer_c *avcpacketizer = new mpeg4_p10_es_video_packetizer_c(this, m_ti, track->v_avcc, track->v_width, track->v_height);
-  track->ptzr                                    = add_packetizer(avcpacketizer);
   show_packetizer_info(m_ti.m_id, PTZR(track->ptzr));
-
-  if (track->v_frame_rate)
-    avcpacketizer->set_track_default_duration(static_cast<int64_t>(1000000000.0 / track->v_frame_rate));
-
-  // This is intentional so that the AVC parser knows the actual
-  // default duration from above but only generates timecode in
-  // emergencies.
-  avcpacketizer->enable_timecode_generation(false);
 }
 
 void
@@ -1192,7 +1122,7 @@ mpeg_ts_reader_c::finish() {
 
   for (auto &track : tracks)
     if ((-1 != track->ptzr) && (0 < track->pes_payload->get_size()))
-      PTZR(track->ptzr)->process(new packet_t(clone_memory(track->pes_payload->get_buffer(), track->pes_payload->get_size())));
+      PTZR(track->ptzr)->process(new packet_t(memory_c::clone(track->pes_payload->get_buffer(), track->pes_payload->get_size())));
 
   file_done = true;
 
