@@ -26,23 +26,25 @@
 class truehd_reader_c: public generic_reader_c {
 private:
   memory_cptr m_chunk;
-  mm_io_cptr m_io;
-  int64_t m_bytes_processed, m_file_size;
   truehd_frame_cptr m_header;
 
 public:
-  truehd_reader_c(track_info_c &_ti) throw (error_c);
+  truehd_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~truehd_reader_c();
 
+  virtual const std::string get_format_name(bool translate = true) {
+    return translate ? Y("TrueHD") : "TrueHD";
+  }
+
+  virtual void read_headers();
   virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false);
-  virtual int get_progress();
   virtual void identify();
   virtual void create_packetizer(int64_t id);
 
-  static int probe_file(mm_io_c *io, uint64_t size);
+  static int probe_file(mm_io_c *in, uint64_t size);
 
 protected:
-  static bool find_valid_headers(mm_io_c *io, int64_t probe_range, int num_headers);
+  static bool find_valid_headers(mm_io_c &in, int64_t probe_range, int num_headers);
 };
 
 #endif // __R_TRUEHD_H
