@@ -43,14 +43,14 @@ wav_demuxer_c::wav_demuxer_c(wav_reader_c *reader,
                              wave_header *wheader)
   : m_reader(reader)
   , m_wheader(wheader)
-  , m_ptzr(NULL)
+  , m_ptzr(nullptr)
   , m_ti(reader->m_ti)
 {
 }
 
 class wav_ac3acm_demuxer_c: public wav_demuxer_c {
 protected:
-  ac3_header_t m_ac3header;
+  ac3::frame_c m_ac3header;
   memory_cptr m_buf[2];
   int m_cur_buf;
   bool m_swap_bytes;
@@ -73,7 +73,7 @@ public:
   virtual void process(int64_t len);
   virtual generic_packetizer_c *create_packetizer();
   virtual std::string get_codec() {
-    return 16 == m_ac3header.bsid ? "EAC3" : "AC3";
+    return m_ac3header.is_eac3() ? "EAC3" : "AC3";
   };
 
 protected:
@@ -201,20 +201,19 @@ wav_ac3acm_demuxer_c::probe(mm_io_cptr &io) {
   int len = io->read(m_buf[m_cur_buf]->get_buffer(), AC3ACM_READ_SIZE);
   io->restore_pos();
 
-  int pos = find_consecutive_ac3_headers(m_buf[m_cur_buf]->get_buffer(), len, 4);
+  ac3::parser_c parser;
+  int pos = parser.find_consecutive_frames(m_buf[m_cur_buf]->get_buffer(), len, 4);
 
   if (-1 == pos) {
     m_swap_bytes = true;
     decode_buffer(len);
-    pos = find_consecutive_ac3_headers(m_buf[m_cur_buf]->get_buffer(), len, 4);
+    pos = parser.find_consecutive_frames(m_buf[m_cur_buf]->get_buffer(), len, 4);
   }
 
   if (-1 == pos)
     return false;
 
-  find_ac3_header(m_buf[m_cur_buf]->get_buffer() + pos, len - pos, &m_ac3header, true);
-
-  return true;
+  return m_ac3header.decode_header(m_buf[m_cur_buf]->get_buffer() + pos, len - pos);
 }
 
 int
@@ -229,7 +228,7 @@ wav_ac3acm_demuxer_c::decode_buffer(int len) {
 
 generic_packetizer_c *
 wav_ac3acm_demuxer_c::create_packetizer() {
-  m_ptzr = new ac3_packetizer_c(m_reader, m_ti, m_ac3header.sample_rate, m_ac3header.channels, m_ac3header.bsid);
+  m_ptzr = new ac3_packetizer_c(m_reader, m_ti, m_ac3header.m_sample_rate, m_ac3header.m_channels, m_ac3header.m_bs_id);
 
   show_packetizer_info(0, m_ptzr);
 
@@ -289,9 +288,10 @@ wav_ac3wav_demuxer_c::decode_buffer(int len) {
   if ((payload_len + 8) > len)
     return -1;
 
-  int pos = find_ac3_header(&base[8], payload_len, &m_ac3header, true);
+  if (!m_ac3header.decode_header(&base[8], payload_len))
+    return -1;
 
-  return 0 == pos ? payload_len : -1;
+  return payload_len;
 }
 
 void
