@@ -41,16 +41,16 @@ kax_block_group_c::add_frame(const KaxTrackEntry &track,
                              int64_t forw_block,
                              LacingType lacing) {
   KaxBlock & block = GetChild<KaxBlock>(*this);
-  assert(NULL != ParentCluster);
+  assert(nullptr != ParentCluster);
   block.SetParent(*ParentCluster);
 
   ParentTrack                     = &track;
   bool result                     = block.AddFrame(track, timecode, buffer, lacing);
-  kax_reference_block_c *past_ref = NULL;
+  kax_reference_block_c *past_ref = nullptr;
 
   if (0 <= past_block) {
     past_ref = FindChild<kax_reference_block_c>(*this);
-    if (NULL == past_ref) {
+    if (nullptr == past_ref) {
       past_ref = new kax_reference_block_c;
       PushElement(*past_ref);
     }
@@ -85,7 +85,7 @@ kax_block_blob_c::add_frame_auto(const KaxTrackEntry &track,
           && (-1 == past_block)
           && (-1 == forw_block))) {
     assert(true == bUseSimpleBlock);
-    if (NULL == Block.simpleblock) {
+    if (nullptr == Block.simpleblock) {
       Block.simpleblock = new KaxSimpleBlock();
       Block.simpleblock->SetParent(*ParentCluster);
     }
@@ -118,15 +118,15 @@ kax_block_blob_c::replace_simple_by_group() {
     return false;
 
   if (!bUseSimpleBlock) {
-    if (NULL == Block.group)
+    if (nullptr == Block.group)
       Block.group = new kax_block_group_c();
 
-  } else if (NULL != Block.simpleblock)
+  } else if (nullptr != Block.simpleblock)
     assert(false);
   else
     Block.group = new kax_block_group_c();
 
-  if (NULL != ParentCluster)
+  if (nullptr != ParentCluster)
     Block.group->SetParent(*ParentCluster);
 
   bUseSimpleBlock = false;
@@ -150,7 +150,7 @@ kax_cluster_c::delete_non_blocks() {
   unsigned idx;
   for (idx = 0; ListSize() > idx; ++idx) {
     EbmlElement *e = (*this)[idx];
-    if ((NULL == dynamic_cast<kax_block_group_c *>(e)) && (NULL == dynamic_cast<KaxSimpleBlock *>(e)))
+    if ((nullptr == dynamic_cast<kax_block_group_c *>(e)) && (nullptr == dynamic_cast<KaxSimpleBlock *>(e)))
       delete e;
   }
 
