@@ -316,7 +316,7 @@ create_track_number(generic_reader_c *reader,
   if (found) {
     found = false;
     for (i = 0; i < g_packetizers.size(); i++)
-      if ((g_packetizers[i].packetizer != NULL) &&
+      if ((g_packetizers[i].packetizer != nullptr) &&
           (g_packetizers[i].packetizer->get_track_num() == tnum)) {
         tnum = s_track_number;
         break;
@@ -346,21 +346,21 @@ static void
 handle_segmentinfo() {
   // segment families
   KaxSegmentFamily *family = FINDFIRST(g_kax_info_chap, KaxSegmentFamily);
-  while (NULL != family) {
+  while (nullptr != family) {
     g_segfamily_uids.add_family_uid(*family);
     family = FINDNEXT(g_kax_info_chap, KaxSegmentFamily, family);
   }
 
   EbmlBinary *uid = FINDFIRST(g_kax_info_chap, KaxSegmentUID);
-  if (NULL != uid)
+  if (nullptr != uid)
     g_forced_seguids.push_back(bitvalue_cptr(new bitvalue_c(*uid)));
 
   uid = FINDFIRST(g_kax_info_chap, KaxNextUID);
-  if (NULL != uid)
+  if (nullptr != uid)
     g_seguid_link_next = bitvalue_cptr(new bitvalue_c(*uid));
 
   uid = FINDFIRST(g_kax_info_chap, KaxPrevUID);
-  if (NULL != uid)
+  if (nullptr != uid)
     g_seguid_link_previous = bitvalue_cptr(new bitvalue_c(*uid));
 }
 
@@ -419,15 +419,19 @@ identify(std::string &filename) {
 
    This function parsers a number that is postfixed with one of the
    four units 's', 'ms', 'us' or 'ns'. If the postfix is 'fps' then
-   this means 'frames per second'. It returns a number of nanoseconds.
+   this means 'frames per second'. If the postfix is 'p' or 'i' then
+   it is also interpreted as the number of 'progressive frames per
+   second' or 'interlaced frames per second'.
+
+   It returns a number of nanoseconds.
 */
 int64_t
 parse_number_with_unit(const std::string &s,
                        const std::string &subject,
                        const std::string &argument,
                        std::string display_s = "") {
-  boost::regex re1("(-?\\d+\\.?\\d*)(s|ms|us|ns|fps)?", boost::regex::perl | boost::regbase::icase);
-  boost::regex re2("(-?\\d+)/(-?\\d+)(s|ms|us|ns|fps)?", boost::regex::perl | boost::regbase::icase);
+  boost::regex re1("(-?\\d+\\.?\\d*)(s|ms|us|ns|fps|p|i)?",  boost::regex::perl | boost::regbase::icase);
+  boost::regex re2("(-?\\d+)/(-?\\d+)(s|ms|us|ns|fps|p|i)?", boost::regex::perl | boost::regbase::icase);
 
   std::string unit, s_n, s_d;
   int64_t n, d;
@@ -463,10 +467,14 @@ parse_number_with_unit(const std::string &s,
     multiplier = 1000;
   else if (unit == "ns")
     multiplier = 1;
-  else if (unit == "fps") {
+  else if ((unit == "fps") || (unit == "p") || (unit == "i")) {
     if (is_fraction)
-      return 1000000000ll * d / n;
-    else if (29.97 == d_value)
+      return 1000000000ll * d / n / (unit == "i" ? 2 : 1);
+
+    if (unit == "i")
+      d_value /= 2;
+
+    if (29.97 == d_value)
       return (int64_t)(100100000.0 / 3.0);
     else if (23.976 == d_value)
       return (int64_t)(1001000000.0 / 24.0);
@@ -494,7 +502,7 @@ parse_and_add_tags(const std::string &file_name) {
 
   while (tags->ListSize() > 0) {
     KaxTag *tag = dynamic_cast<KaxTag *>((*tags)[0]);
-    if (NULL != tag) {
+    if (nullptr != tag) {
       fix_mandatory_tag_elements(tag);
       if (!tag->CheckMandatory())
         mxerror(boost::format(Y("Error parsing the tags in '%1%': some mandatory elements are missing.\n")) % file_name);
@@ -574,14 +582,14 @@ parse_arg_sync(std::string s,
     s.erase(idx);
     idx = linear.find('/');
     if (idx < 0) {
-      tcsync.numerator   = strtod(linear.c_str(), NULL);
+      tcsync.numerator   = strtod(linear.c_str(), nullptr);
       tcsync.denominator = 1.0;
 
     } else {
       std::string div = linear.substr(idx + 1);
       linear.erase(idx);
-      double d1  = strtod(linear.c_str(), NULL);
-      double d2  = strtod(div.c_str(), NULL);
+      double d1  = strtod(linear.c_str(), nullptr);
+      double d2  = strtod(div.c_str(), nullptr);
       if (0.0 == d2)
         mxerror(boost::format(Y("Invalid sync option specified in '%1% %2%'. The divisor is zero.\n")) % opt % orig);
 
@@ -626,7 +634,7 @@ parse_arg_aspect_ratio(const std::string &s,
   if (0 > idx)
     idx = parts[1].find(':');
   if (0 > idx) {
-    dprop.aspect_ratio          = strtod(parts[1].c_str(), NULL);
+    dprop.aspect_ratio          = strtod(parts[1].c_str(), nullptr);
     ti.m_display_properties[id] = dprop;
     return;
   }
@@ -639,8 +647,8 @@ parse_arg_aspect_ratio(const std::string &s,
   if (div.empty())
     mxerror(boost::format(Y("%1%: missing divisor in '%2% %3%'.\n")) % msg % opt % s);
 
-  double w = strtod(parts[1].c_str(), NULL);
-  double h = strtod(div.c_str(), NULL);
+  double w = strtod(parts[1].c_str(), nullptr);
+  double h = strtod(div.c_str(), nullptr);
   if (0.0 == h)
     mxerror(boost::format(Y("%1%: divisor is 0 in '%2% %3%'.\n")) % msg % opt % s);
 
@@ -1225,7 +1233,7 @@ parse_arg_append_mode(const std::string &s) {
 
    The argument must be a tuple consisting of a track ID and the default
    duration separated by a colon. The duration must be postfixed by 'ms',
-   'us', 'ns' or 'fps' (see \c parse_number_with_unit).
+   'us', 'ns', 'fps', 'p' or 'i' (see \c parse_number_with_unit).
 */
 static void
 parse_arg_default_duration(const std::string &s,
@@ -1461,7 +1469,7 @@ parse_arg_chapters(const std::string &param,
   delete g_kax_chapters;
 
   g_chapter_file_name = arg;
-  g_kax_chapters      = parse_chapters(g_chapter_file_name, 0, -1, 0, g_chapter_language.c_str(), g_chapter_charset.c_str(), false, NULL, &g_tags_from_cue_chapters);
+  g_kax_chapters      = parse_chapters(g_chapter_file_name, 0, -1, 0, g_chapter_language.c_str(), g_chapter_charset.c_str(), false, nullptr, &g_tags_from_cue_chapters);
 }
 
 static void
@@ -1481,7 +1489,7 @@ parse_arg_timecode_scale(const std::string &arg) {
   if (TIMECODE_SCALE_MODE_NORMAL != g_timecode_scale_mode)
     mxerror(Y("'--timecode-scale' was used more than once.\n"));
 
-  int64_t temp =0 ;
+  int64_t temp = 0;
   if (!parse_int(arg, temp))
     mxerror(Y("The argument to '--timecode-scale' must be a number.\n"));
 
