@@ -67,7 +67,7 @@ generic_packetizer_c::generic_packetizer_c(generic_reader_c *reader,
   , m_enqueued_bytes(0)
   , m_safety_last_timecode(0)
   , m_safety_last_duration(0)
-  , m_track_entry(NULL)
+  , m_track_entry(nullptr)
   , m_hserialno(-1)
   , m_htrack_type(-1)
   , m_htrack_min_cache(0)
@@ -77,7 +77,7 @@ generic_packetizer_c::generic_packetizer_c(generic_reader_c *reader,
   , m_default_track_warning_printed(false)
   , m_huid(0)
   , m_htrack_max_add_block_ids(-1)
-  , m_hcodec_private(NULL)
+  , m_hcodec_private(nullptr)
   , m_hcodec_private_length(0)
   , m_haudio_sampling_freq(-1.0)
   , m_haudio_output_sampling_freq(-1.0)
@@ -131,6 +131,12 @@ generic_packetizer_c::generic_packetizer_c(generic_reader_c *reader,
   else if (map_has_key(m_ti.m_forced_track_flags, -1))
     m_ti.m_forced_track = m_ti.m_forced_track_flags[-1];
 
+  // Let's see if the user has given a enabled track flag for this track.
+  if (map_has_key(m_ti.m_enabled_track_flags, m_ti.m_id))
+    m_ti.m_enabled_track = m_ti.m_enabled_track_flags[m_ti.m_id];
+  else if (map_has_key(m_ti.m_enabled_track_flags, -1))
+    m_ti.m_enabled_track = m_ti.m_enabled_track_flags[-1];
+
   // Let's see if the user has specified a language for this track.
   if (map_has_key(m_ti.m_languages, m_ti.m_id))
     m_ti.m_language = m_ti.m_languages[m_ti.m_id];
@@ -253,7 +259,7 @@ generic_packetizer_c::~generic_packetizer_c() {
 
 void
 generic_packetizer_c::set_tag_track_uid() {
-  if (NULL == m_ti.m_tags)
+  if (nullptr == m_ti.m_tags)
     return;
 
   convert_old_tags(*m_ti.m_tags);
@@ -278,7 +284,7 @@ generic_packetizer_c::set_uid(uint32_t uid) {
   if (is_unique_uint32(uid, UNIQUE_TRACK_IDS)) {
     add_unique_uint32(uid, UNIQUE_TRACK_IDS);
     m_huid = uid;
-    if (NULL != m_track_entry)
+    if (nullptr != m_track_entry)
       GetChildAs<KaxTrackUID, EbmlUInteger>(m_track_entry) = m_huid;
 
     return 1;
@@ -300,7 +306,7 @@ generic_packetizer_c::set_track_type(int type,
 
   else if (track_video == type) {
     m_reader->m_num_video_tracks++;
-    if (NULL == g_video_packetizer)
+    if (nullptr == g_video_packetizer)
       g_video_packetizer = this;
 
   } else
@@ -324,14 +330,14 @@ generic_packetizer_c::set_track_type(int type,
 void
 generic_packetizer_c::set_track_name(const std::string &name) {
   m_ti.m_track_name = name;
-  if ((NULL != m_track_entry) && !name.empty())
+  if ((nullptr != m_track_entry) && !name.empty())
     GetChildAs<KaxTrackName, EbmlUnicodeString>(m_track_entry) = cstrutf8_to_UTFstring(m_ti.m_track_name);
 }
 
 void
 generic_packetizer_c::set_codec_id(const std::string &id) {
   m_hcodec_id = id;
-  if ((NULL != m_track_entry) && !id.empty())
+  if ((nullptr != m_track_entry) && !id.empty())
     GetChildAs<KaxCodecID, EbmlString>(m_track_entry) = m_hcodec_id;
 }
 
@@ -340,8 +346,8 @@ generic_packetizer_c::set_codec_private(const unsigned char *cp,
                                         int length) {
   safefree(m_hcodec_private);
 
-  if (NULL == cp) {
-    m_hcodec_private        = NULL;
+  if (nullptr == cp) {
+    m_hcodec_private        = nullptr;
     m_hcodec_private_length = 0;
     return;
   }
@@ -349,21 +355,21 @@ generic_packetizer_c::set_codec_private(const unsigned char *cp,
   m_hcodec_private        = (unsigned char *)safememdup(cp, length);
   m_hcodec_private_length = length;
 
-  if (NULL != m_track_entry)
+  if (nullptr != m_track_entry)
     GetChild<KaxCodecPrivate>(*m_track_entry).CopyBuffer((binary *)m_hcodec_private, m_hcodec_private_length);
 }
 
 void
 generic_packetizer_c::set_track_min_cache(int min_cache) {
   m_htrack_min_cache = min_cache;
-  if (NULL != m_track_entry)
+  if (nullptr != m_track_entry)
     GetChildAs<KaxTrackMinCache, EbmlUInteger>(m_track_entry) = min_cache;
 }
 
 void
 generic_packetizer_c::set_track_max_cache(int max_cache) {
   m_htrack_max_cache = max_cache;
-  if (NULL != m_track_entry)
+  if (nullptr != m_track_entry)
     GetChildAs<KaxTrackMaxCache, EbmlUInteger>(m_track_entry) = max_cache;
 }
 
@@ -374,14 +380,14 @@ generic_packetizer_c::set_track_default_duration(int64_t def_dur) {
 
   m_htrack_default_duration = (int64_t)(def_dur * m_ti.m_tcsync.numerator / m_ti.m_tcsync.denominator);
 
-  if (NULL != m_track_entry)
+  if (nullptr != m_track_entry)
     GetChildAs<KaxTrackDefaultDuration, EbmlUInteger>(m_track_entry) = m_htrack_default_duration;
 }
 
 void
 generic_packetizer_c::set_track_max_additionals(int max_add_block_ids) {
   m_htrack_max_add_block_ids = max_add_block_ids;
-  if (NULL != m_track_entry)
+  if (nullptr != m_track_entry)
     GetChildAs<KaxMaxBlockAdditionID, EbmlUInteger>(m_track_entry) = max_add_block_ids;
 }
 
@@ -393,70 +399,84 @@ generic_packetizer_c::get_track_default_duration() {
 void
 generic_packetizer_c::set_track_forced_flag(bool forced_track) {
   m_ti.m_forced_track = forced_track;
-  if (NULL != m_track_entry)
+  if (nullptr != m_track_entry)
     GetChildAs<KaxTrackFlagForced, EbmlUInteger>(m_track_entry) = forced_track ? 1 : 0;
 }
 
+void
+generic_packetizer_c::set_track_enabled_flag(bool enabled_track) {
+  m_ti.m_enabled_track = enabled_track;
+  if (nullptr != m_track_entry)
+    GetChildAs<KaxTrackFlagEnabled, EbmlUInteger>(m_track_entry) = enabled_track ? 1 : 0;
+}
+
 void
 generic_packetizer_c::set_audio_sampling_freq(float freq) {
   m_haudio_sampling_freq = freq;
-  if (NULL != m_track_entry)
+  if (nullptr != m_track_entry)
     GetChildAs<KaxAudioSamplingFreq, EbmlFloat>(GetChild<KaxTrackAudio>(m_track_entry)) = m_haudio_sampling_freq;
 }
 
 void
 generic_packetizer_c::set_audio_output_sampling_freq(float freq) {
   m_haudio_output_sampling_freq = freq;
-  if (NULL != m_track_entry)
+  if (nullptr != m_track_entry)
     GetChildAs<KaxAudioOutputSamplingFreq, EbmlFloat>(GetChild<KaxTrackAudio>(m_track_entry)) = m_haudio_output_sampling_freq;
 }
 
 void
 generic_packetizer_c::set_audio_channels(int channels) {
   m_haudio_channels = channels;
-  if (NULL != m_track_entry)
+  if (nullptr != m_track_entry)
     GetChildAs<KaxAudioChannels, EbmlUInteger>(GetChild<KaxTrackAudio>(*m_track_entry)) = m_haudio_channels;
 }
 
 void
 generic_packetizer_c::set_audio_bit_depth(int bit_depth) {
   m_haudio_bit_depth = bit_depth;
-  if (NULL != m_track_entry)
+  if (nullptr != m_track_entry)
     GetChildAs<KaxAudioBitDepth, EbmlUInteger>(GetChild<KaxTrackAudio>(*m_track_entry)) = m_haudio_bit_depth;
 }
 
 void
 generic_packetizer_c::set_video_interlaced_flag(bool interlaced) {
   m_hvideo_interlaced_flag = interlaced ? 1 : 0;
-  if (NULL != m_track_entry)
+  if (nullptr != m_track_entry)
     GetChildAs<KaxVideoFlagInterlaced, EbmlUInteger>(GetChild<KaxTrackVideo>(*m_track_entry)) = m_hvideo_interlaced_flag;
 }
 
 void
 generic_packetizer_c::set_video_pixel_width(int width) {
   m_hvideo_pixel_width = width;
-  if (NULL != m_track_entry)
+  if (nullptr != m_track_entry)
     GetChildAs<KaxVideoPixelWidth, EbmlUInteger>(GetChild<KaxTrackVideo>(*m_track_entry)) = m_hvideo_pixel_width;
 }
 
 void
 generic_packetizer_c::set_video_pixel_height(int height) {
   m_hvideo_pixel_height = height;
-  if (NULL != m_track_entry)
+  if (nullptr != m_track_entry)
     GetChildAs<KaxVideoPixelHeight, EbmlUInteger>(GetChild<KaxTrackVideo>(*m_track_entry)) = m_hvideo_pixel_height;
 }
 
+void
+generic_packetizer_c::set_video_pixel_dimensions(int width,
+                                                 int height) {
+  set_video_pixel_width(width);
+  set_video_pixel_height(height);
+}
+
 void
 generic_packetizer_c::set_video_display_width(int width) {
   m_hvideo_display_width = width;
-  if (NULL != m_track_entry)
+  if (nullptr != m_track_entry)
     GetChildAs<KaxVideoDisplayWidth, EbmlUInteger>(GetChild<KaxTrackVideo>(*m_track_entry)) = m_hvideo_display_width;
 }
 
 void
 generic_packetizer_c::set_video_display_height(int height) {
   m_hvideo_display_height = height;
-  if (NULL != m_track_entry)
+  if (nullptr != m_track_entry)
     GetChildAs<KaxVideoDisplayHeight, EbmlUInteger>(GetChild<KaxTrackVideo>(*m_track_entry)) = m_hvideo_display_height;
 }
 
@@ -511,7 +531,7 @@ generic_packetizer_c::set_as_default_track(int type,
 void
 generic_packetizer_c::set_language(const std::string &language) {
   m_ti.m_language = language;
-  if (NULL != m_track_entry)
+  if (nullptr != m_track_entry)
     GetChildAs<KaxTrackLanguage, EbmlString>(m_track_entry) = m_ti.m_language;
 }
 
@@ -530,7 +550,7 @@ generic_packetizer_c::set_video_pixel_cropping(int left,
   m_ti.m_pixel_cropping.bottom = bottom;
   m_ti.m_pixel_cropping_source = source;
 
-  if (NULL != m_track_entry) {
+  if (nullptr != m_track_entry) {
     KaxTrackVideo &video = GetChild<KaxTrackVideo>(m_track_entry);
 
     GetChildAs<KaxVideoPixelCropLeft,   EbmlUInteger>(video) = m_ti.m_pixel_cropping.left;
@@ -555,7 +575,7 @@ generic_packetizer_c::set_video_stereo_mode(stereo_mode_c::mode stereo_mode,
   m_ti.m_stereo_mode        = stereo_mode;
   m_ti.m_stereo_mode_source = source;
 
-  if ((NULL != m_track_entry) && (stereo_mode_c::unspecified != stereo_mode))
+  if ((nullptr != m_track_entry) && (stereo_mode_c::unspecified != stereo_mode))
     set_video_stereo_mode_impl(GetChild<KaxTrackVideo>(*m_track_entry), m_ti.m_stereo_mode);
 }
 
@@ -591,8 +611,8 @@ generic_packetizer_c::set_headers() {
   if (!found)
     ptzrs_in_header_order.push_back(this);
 
-  if (NULL == m_track_entry) {
-    m_track_entry    = NULL == g_kax_last_entry ? &GetChild<KaxTrackEntry>(g_kax_tracks) : &GetNextChild<KaxTrackEntry>(*g_kax_tracks, *g_kax_last_entry);
+  if (nullptr == m_track_entry) {
+    m_track_entry    = nullptr == g_kax_last_entry ? &GetChild<KaxTrackEntry>(g_kax_tracks) : &GetNextChild<KaxTrackEntry>(*g_kax_tracks, *g_kax_last_entry);
     g_kax_last_entry = m_track_entry;
     m_track_entry->SetGlobalTimecodeScale((int64_t)g_timecode_scale);
   }
@@ -610,7 +630,7 @@ generic_packetizer_c::set_headers() {
   if (!m_hcodec_id.empty())
     GetChildAs<KaxCodecID, EbmlString>(m_track_entry)     = m_hcodec_id;
 
-  if (NULL != m_hcodec_private)
+  if (nullptr != m_hcodec_private)
     GetChild<KaxCodecPrivate>(*m_track_entry).CopyBuffer((binary *)m_hcodec_private, m_hcodec_private_length);
 
   if (!outputting_webm()) {
@@ -646,6 +666,9 @@ generic_packetizer_c::set_headers() {
   if (!boost::logic::indeterminate(m_ti.m_forced_track))
     GetChildAs<KaxTrackFlagForced, EbmlUInteger>(m_track_entry) = m_ti.m_forced_track ? 1 : 0;
 
+  if (!boost::logic::indeterminate(m_ti.m_enabled_track))
+    GetChildAs<KaxTrackFlagEnabled, EbmlUInteger>(m_track_entry) = m_ti.m_enabled_track ? 1 : 0;
+
   if (track_video == m_htrack_type) {
     KaxTrackVideo &video = GetChild<KaxTrackVideo>(m_track_entry);
 
@@ -736,7 +759,7 @@ generic_packetizer_c::set_headers() {
     m_track_entry->EnableLacing(false);
 
   set_tag_track_uid();
-  if (NULL != m_ti.m_tags) {
+  if (nullptr != m_ti.m_tags) {
     while (m_ti.m_tags->ListSize() != 0) {
       KaxTag *tag = (KaxTag *)(*m_ti.m_tags)[0];
       add_tags(tag);
@@ -759,7 +782,7 @@ generic_packetizer_c::add_packet(packet_cptr pack) {
 
   ++m_num_packets;
 
-  if (NULL == m_reader->m_ptzr_first_packet)
+  if (nullptr == m_reader->m_ptzr_first_packet)
     m_reader->m_ptzr_first_packet = this;
 
   // strip elements to be removed
@@ -874,7 +897,7 @@ generic_packetizer_c::process_deferred_packets() {
 packet_cptr
 generic_packetizer_c::get_packet() {
   if (m_packet_queue.empty() || !m_packet_queue.front()->factory_applied)
-    return packet_cptr(NULL);
+    return packet_cptr(nullptr);
 
   packet_cptr pack = m_packet_queue.front();
   m_packet_queue.pop_front();
@@ -969,7 +992,7 @@ struct packet_sorter_t {
   }
 };
 
-std::deque<packet_cptr> *packet_sorter_t::m_packet_queue = NULL;
+std::deque<packet_cptr> *packet_sorter_t::m_packet_queue = nullptr;
 
 void
 generic_packetizer_c::apply_factory_full_queueing(packet_cptr_di &p_start) {
@@ -1121,9 +1144,9 @@ generic_reader_c::generic_reader_c(const track_info_c &ti,
   : m_ti(ti)
   , m_in(in)
   , m_size(in->get_size())
-  , m_ptzr_first_packet(NULL)
+  , m_ptzr_first_packet(nullptr)
   , m_max_timecode_seen(0)
-  , m_chapters(NULL)
+  , m_chapters(nullptr)
   , m_appending(false)
   , m_num_video_tracks(0)
   , m_num_audio_tracks(0)
@@ -1177,9 +1200,9 @@ generic_reader_c::demuxing_requested(char type,
                                 : 's' == type ? &m_ti.m_stracks
                                 : 'b' == type ? &m_ti.m_btracks
                                 : 'T' == type ? &m_ti.m_track_tags
-                                :               NULL;
+                                :               nullptr;
 
-  if (NULL == tracks)
+  if (nullptr == tracks)
     mxerror(boost::format(Y("pr_generic.cpp/generic_reader_c::demuxing_requested(): Invalid track type %1%.")) % type);
 
   return tracks->selected(id);
@@ -1473,7 +1496,7 @@ track_info_c::track_info_c()
   : m_initialized(true)
   , m_id(0)
   , m_disable_multi_file(false)
-  , m_private_data(NULL)
+  , m_private_data(nullptr)
   , m_private_size(0)
   , m_aspect_ratio(0.0)
   , m_display_width(0)
@@ -1486,7 +1509,8 @@ track_info_c::track_info_c()
   , m_cues(CUE_STRATEGY_UNSPECIFIED)
   , m_default_track(boost::logic::indeterminate)
   , m_forced_track(boost::logic::indeterminate)
-  , m_tags(NULL)
+  , m_enabled_track(boost::logic::indeterminate)
+  , m_tags(nullptr)
   , m_compression(COMPRESSION_UNSPECIFIED)
   , m_pixel_cropping_source(PARAMETER_SOURCE_NONE)
   , m_stereo_mode(stereo_mode_c::unspecified)
@@ -1555,6 +1579,9 @@ track_info_c::operator =(const track_info_c &src) {
   m_forced_track_flags         = src.m_forced_track_flags;
   m_forced_track               = src.m_forced_track;
 
+  m_enabled_track_flags        = src.m_enabled_track_flags;
+  m_enabled_track              = src.m_enabled_track;
+
   m_languages                  = src.m_languages;
   m_language                   = src.m_language;
 
@@ -1563,7 +1590,7 @@ track_info_c::operator =(const track_info_c &src) {
 
   m_all_tags                   = src.m_all_tags;
   m_tags_file_name             = src.m_tags_file_name;
-  m_tags                       = NULL != src.m_tags ? static_cast<KaxTags *>(src.m_tags->Clone()) : NULL;
+  m_tags                       = nullptr != src.m_tags ? static_cast<KaxTags *>(src.m_tags->Clone()) : nullptr;
 
   m_all_aac_is_sbr             = src.m_all_aac_is_sbr;
 
