@@ -14,17 +14,10 @@
 #ifndef __TIMECODE_FACTORY_H
 #define __TIMECODE_FACTORY_H
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
-#include <string>
-#include <vector>
-
-#include "common/smart_pointers.h"
 #include "merge/packet.h"
 
-
-class mm_io_c;
-
 enum timecode_factory_application_e {
   TFA_AUTOMATIC,
   TFA_IMMEDIATE,
@@ -57,7 +50,7 @@ protected:
   std::string m_file_name, m_source_name;
   int64_t m_tid;
   int m_version;
-  bool m_preserve_duration;
+  bool m_preserve_duration, m_debug;
 
 public:
   timecode_factory_c(const std::string &file_name,
@@ -69,6 +62,7 @@ public:
     , m_tid(tid)
     , m_version(version)
     , m_preserve_duration(false)
+    , m_debug(debugging_requested("timecode_factory"))
   {
   }
   virtual ~timecode_factory_c() {
@@ -131,7 +125,7 @@ class timecode_factory_v2_c: public timecode_factory_c {
 protected:
   std::vector<int64_t> m_timecodes, m_durations;
   int64_t m_frameno;
-  double m_default_fps;
+  double m_default_duration;
   bool m_warning_printed;
 
 public:
@@ -140,7 +134,7 @@ public:
                         int64_t tid, int version)
     : timecode_factory_c(file_name, source_name, tid, version)
     , m_frameno(0)
-    , m_default_fps(0.0)
+    , m_default_duration(0)
     , m_warning_printed(false)
   {
   }
@@ -150,7 +144,7 @@ public:
   virtual void parse(mm_io_c &in);
   virtual bool get_next(packet_cptr &packet);
   virtual double get_default_duration(double proposal) {
-    return m_default_fps != 0.0 ? static_cast<double>(1000000000.0) / m_default_fps : proposal;
+    return m_default_duration != 0 ? m_default_duration : proposal;
   }
 };
 
