@@ -31,7 +31,7 @@ he_unsigned_integer_value_page_c::he_unsigned_integer_value_page_c(header_editor
                                                                    const translatable_string_c &title,
                                                                    const translatable_string_c &description)
   : he_value_page_c(parent, toplevel_page, master, callbacks, vt_unsigned_integer, title, description)
-  , m_tc_text(NULL)
+  , m_tc_text(nullptr)
   , m_original_value(0)
 {
 }
@@ -41,7 +41,7 @@ he_unsigned_integer_value_page_c::~he_unsigned_integer_value_page_c() {
 
 wxControl *
 he_unsigned_integer_value_page_c::create_input_control() {
-  if (NULL != m_element)
+  if (nullptr != m_element)
     m_original_value = uint64(*static_cast<EbmlUInteger *>(m_element));
 
   m_tc_text = new wxTextCtrl(this, wxID_ANY, get_original_value_as_string());
@@ -52,7 +52,7 @@ he_unsigned_integer_value_page_c::create_input_control() {
 
 wxString
 he_unsigned_integer_value_page_c::get_original_value_as_string() {
-  if (NULL != m_element)
+  if (nullptr != m_element)
     return wxString::Format(wxU("%") + wxU(wxLongLongFmtSpec) + wxU("u"), m_original_value);
 
   return wxEmptyString;
