@@ -60,7 +60,7 @@ const wxChar *predefined_aspect_ratios[] = {
   wxT("2.00"),
   wxT("2.21"),
   wxT("2.35"),
-  NULL
+  nullptr
 };
 
 const wxChar *predefined_fourccs[] = {
@@ -70,7 +70,7 @@ const wxChar *predefined_fourccs[] = {
   wxT("DX50"),
   wxT("MP4V"),
   wxT("XVID"),
-  NULL
+  nullptr
 };
 
 class input_drop_target_c: public wxFileDropTarget {
@@ -165,7 +165,7 @@ tab_input::tab_input(wxWindow *parent):
 
   translate_ui();
 
-  set_track_mode(NULL);
+  set_track_mode(nullptr);
   selected_file  = -1;
   selected_track = -1;
 
@@ -178,7 +178,6 @@ tab_input::tab_input(wxWindow *parent):
   wxConfig *cfg = (wxConfig *)wxConfigBase::Get();
 
   cfg->SetPath(wxT("/GUI"));
-  cfg->Read(wxT("avc_es_fps_warning_shown"), &avc_es_fps_warning_shown, false);
 }
 
 void
@@ -262,7 +261,7 @@ tab_input::setup_file_type_filter() {
 
 void
 tab_input::select_file(bool append) {
-  wxFileDialog dlg(NULL, append ? Z("Choose an input file to append") : Z("Choose an input file to add"), last_open_dir, wxEmptyString, setup_file_type_filter(), wxFD_OPEN | wxFD_MULTIPLE);
+  wxFileDialog dlg(nullptr, append ? Z("Choose an input file to append") : Z("Choose an input file to add"), last_open_dir, wxEmptyString, setup_file_type_filter(), wxFD_OPEN | wxFD_MULTIPLE);
   if(dlg.ShowModal() != wxID_OK)
     return;
 
@@ -486,24 +485,6 @@ tab_input::add_file(const wxString &file_name,
 
       file->tracks.push_back(track);
 
-      if (   (FILE_TYPE_AVC_ES == file->container)
-          && !track->appending
-          && ('v' == track->type)
-          && (track->ctype.Find(wxT("MPEG-4 part 10 ES")) >= 0)
-          && (!avc_es_fps_warning_shown || mdlg->options.warn_usage)) {
-        wxMessageBox(Z("You're adding an AVC/h.264 elementary stream to the output file. "
-                       "mkvmerge cannot determine the number of frames per second for such files itself. "
-                       "Therefore you have to set this parameter yourself on the 'format specific options' page.\n\n"
-                       "If you don't do this then mkvmerge will assume 25 fps.\n\n"
-                       "This message will only be shown once unless you have enabled mmg's warnings on its 'settings' page."));
-        avc_es_fps_warning_shown = true;
-
-        wxConfig *cfg = (wxConfig *)wxConfigBase::Get();
-        cfg->SetPath(wxT("/GUI"));
-        cfg->Write(wxT("avc_es_fps_warning_shown"), true);
-        cfg->Flush();
-      }
-
       if (   mdlg->options.disable_a_v_compression
           && !track->appending
           && (('v' == track->type) || ('a' == track->type)))
@@ -776,7 +757,7 @@ tab_input::on_remove_file(wxCommandEvent &) {
   b_track_down->Enable(-1 != selected_file);
 
   selected_track = clb_tracks->GetSelection();
-  set_track_mode(-1 == selected_track ? NULL : tracks[selected_track]);
+  set_track_mode(-1 == selected_track ? nullptr : tracks[selected_track]);
   if (tracks.empty()) {
     st_tracks->Enable(false);
     clb_tracks->Enable(false);
@@ -808,7 +789,7 @@ tab_input::on_remove_all_files(wxCommandEvent &) {
   b_track_up->Enable(false);
   b_track_down->Enable(false);
 
-  set_track_mode(NULL);
+  set_track_mode(nullptr);
 
   mdlg->remove_output_filename();
 
@@ -1075,7 +1056,7 @@ tab_input::load(wxConfigBase *cfg,
 
   clb_tracks->Clear();
   lb_input_files->Clear();
-  set_track_mode(NULL);
+  set_track_mode(nullptr);
   selected_file  = -1;
   selected_track = -1;
   b_remove_file->Enable(false);
@@ -1333,28 +1314,14 @@ tab_input::validate_settings() {
       str = t->fps;
       strip(str);
       if (str.length() > 0) {
-        wxRegEx re_fps1(wxT("^[[:digit:]]+\\.?[[:digit:]]*$"));
-        wxRegEx re_fps2(wxT("^[[:digit:]]+/[[:digit:]]+$"));
+        wxRegEx re_fps1(wxT("^[[:digit:]]+\\.?[[:digit:]]*[ip]?$"));
+        wxRegEx re_fps2(wxT("^[[:digit:]]+/[[:digit:]]+[ip]?$"));
         if (!re_fps1.Matches(str) && !re_fps2.Matches(str)) {
           wxString err;
           err.Printf(Z("The FPS setting for track nr. %s in file '%s' is invalid."), sid.c_str(), f->file_name.c_str());
           wxMessageBox(err, Z("mkvmerge GUI: error"), wxOK | wxCENTER | wxICON_ERROR);
           return false;
         }
-      } else if (   (FILE_TYPE_AVC_ES == f->container)
-                 && !t->appending
-                 && ('v' == t->type)
-                 && (t->ctype.Find(wxT("MPEG-4 part 10 ES")) >= 0)
-                 && mdlg->options.warn_usage) {
-        wxString message;
-        message.Printf(Z("You haven't selected a number of frames per second for track %lld of file '%s'. "
-                         "mkvmerge cannot determine the number of frames per second for such files itself. "
-                         "Therefore you have to set this parameter yourself on the 'format specific options' page.\n\n"
-                         "If you don't do this then mkvmerge will assume 25 fps.\n\n"
-                         "Do you still want to continue?"),
-                       t->id, f->file_name.c_str());
-        if (wxMessageBox(message, Z("No FPS selected for AVC/h.264 track"), wxYES | wxNO, mdlg) == wxNO)
-          return false;
       }
 
       s = wxMB(t->aspect_ratio);
