@@ -29,17 +29,14 @@ ac3_packetizer_c::ac3_packetizer_c(generic_reader_c *p_reader,
   : generic_packetizer_c(p_reader, p_ti)
   , m_bytes_output(0)
   , m_packetno(0)
-  , m_bytes_skipped(0)
   , m_last_timecode(-1)
   , m_num_packets_same_tc(0)
-  , m_samples_per_sec(samples_per_sec)
-  , m_first_packet(true)
-  , m_s2tc(1536 * 1000000000ll, m_samples_per_sec)
+  , m_s2tc(1536 * 1000000000ll, samples_per_sec)
   , m_single_packet_duration(1 * m_s2tc)
 {
-  memset(&m_first_ac3_header, 0, sizeof(ac3_header_t));
-  m_first_ac3_header.bsid     = bsid;
-  m_first_ac3_header.channels = channels;
+  m_first_ac3_header.m_sample_rate = samples_per_sec;
+  m_first_ac3_header.m_bs_id       = bsid;
+  m_first_ac3_header.m_channels    = channels;
 
   set_track_type(track_audio);
   set_track_default_duration(m_single_packet_duration);
@@ -50,125 +47,127 @@ ac3_packetizer_c::ac3_packetizer_c(generic_reader_c *p_reader,
 ac3_packetizer_c::~ac3_packetizer_c() {
 }
 
-void
-ac3_packetizer_c::add_to_buffer(unsigned char *buf,
-                                int size) {
-  m_byte_buffer.add(buf, size);
-}
+ac3::frame_c
+ac3_packetizer_c::get_frame() {
+  ac3::frame_c frame = m_parser.get_frame();
 
-unsigned char *
-ac3_packetizer_c::get_ac3_packet(ac3_header_t *ac3header) {
-  unsigned char *packet_buffer = m_byte_buffer.get_buffer();
-  size_t size                  = m_byte_buffer.get_size();
+  if (0 == frame.m_garbage_size)
+    return frame;
 
-  if (NULL == packet_buffer)
-    return NULL;
+  bool warning_printed = false;
+  if (0 == m_packetno) {
+    int64_t offset = handle_avi_audio_sync(frame.m_garbage_size, false);
+    if (-1 != offset) {
+      mxinfo_tid(m_ti.m_fname, m_ti.m_id,
+                 boost::format(Y("This AC3 track contains %1% bytes of non-AC3 data at the beginning. "
+                                 "This corresponds to a delay of %2%ms. "
+                                 "This delay will be used instead of the non-AC3 data.\n"))
+                 % frame.m_garbage_size % (offset / 1000000));
 
-  int pos = find_ac3_header(packet_buffer, size, ac3header, m_first_packet || m_first_ac3_header.has_dependent_frames);
-
-  if ((0 > pos) || (static_cast<size_t>(pos + ac3header->bytes) > size))
-    return NULL;
-
-  m_bytes_skipped += pos;
-  if (0 < m_bytes_skipped) {
-    bool warning_printed = false;
-    if (0 == m_packetno) {
-      int64_t offset = handle_avi_audio_sync(m_bytes_skipped, false);
-      if (-1 != offset) {
-        mxinfo_tid(m_ti.m_fname, m_ti.m_id,
-                   boost::format(Y("This AC3 track contains %1% bytes of non-AC3 data at the beginning. "
-                                   "This corresponds to a delay of %2%ms. "
-                                   "This delay will be used instead of the non-AC3 data.\n"))
-                   % m_bytes_skipped % (offset / 1000000));
-
-        warning_printed             = true;
-        m_ti.m_tcsync.displacement += offset;
-      }
+      warning_printed             = true;
+      m_ti.m_tcsync.displacement += offset;
     }
-
-    if (!warning_printed)
-      mxwarn_tid(m_ti.m_fname, m_ti.m_id,
-                 boost::format(Y("This AC3 track contains %1% bytes of non-AC3 data which were skipped. "
-                                 "The audio/video synchronization may have been lost.\n")) % m_bytes_skipped);
-
-    m_byte_buffer.remove(pos);
-    packet_buffer   = m_byte_buffer.get_buffer();
-    size            = m_byte_buffer.get_size();
-    pos             = 0;
-    m_bytes_skipped = 0;
   }
 
-  unsigned char *buf = (unsigned char *)safememdup(packet_buffer, ac3header->bytes);
+  if (!warning_printed)
+    mxwarn_tid(m_ti.m_fname, m_ti.m_id,
+               boost::format(Y("This AC3 track contains %1% bytes of non-AC3 data which were skipped. "
+                               "The audio/video synchronization may have been lost.\n")) % frame.m_garbage_size);
 
-  m_byte_buffer.remove(ac3header->bytes);
-
-  return buf;
+  return frame;
 }
 
 void
 ac3_packetizer_c::set_headers() {
   std::string id = MKV_A_AC3;
 
-  if (9 == m_first_ac3_header.bsid)
-    id += "/BSID9";
-  else if (10 == m_first_ac3_header.bsid)
-    id += "/BSID10";
-  else if (16 == m_first_ac3_header.bsid)
+  if (m_first_ac3_header.is_eac3())
     id = MKV_A_EAC3;
+  else if (9 == m_first_ac3_header.m_bs_id)
+    id += "/BSID9";
+  else if (10 == m_first_ac3_header.m_bs_id)
+    id += "/BSID10";
 
   set_codec_id(id.c_str());
-  set_audio_sampling_freq((float)m_samples_per_sec);
-  set_audio_channels(m_first_ac3_header.channels);
+  set_audio_sampling_freq((float)m_first_ac3_header.m_sample_rate);
+  set_audio_channels(m_first_ac3_header.m_channels);
 
   generic_packetizer_c::set_headers();
 }
 
 int
 ac3_packetizer_c::process(packet_cptr packet) {
-  unsigned char *ac3_packet;
-  ac3_header_t ac3header;
+  if (-1 != packet->timecode)
+    m_available_timecodes.push_back(std::make_pair(packet->timecode, m_parser.get_total_stream_position()));
 
   add_to_buffer(packet->data->get_buffer(), packet->data->get_size());
-  while ((ac3_packet = get_ac3_packet(&ac3header)) != NULL) {
-    adjust_header_values(ac3header);
-
-    int64_t new_timecode;
-
-    if (-1 != packet->timecode) {
-      new_timecode = packet->timecode;
-      if (m_last_timecode == packet->timecode) {
-        m_num_packets_same_tc++;
-        new_timecode += m_num_packets_same_tc * m_s2tc;
-
-      } else {
-        m_last_timecode       = packet->timecode;
-        m_num_packets_same_tc = 0;
-      }
-
-    } else
-      new_timecode = m_packetno * m_s2tc;
-
-    add_packet(new packet_t(new memory_c(ac3_packet, ac3header.bytes, true), new_timecode, m_single_packet_duration));
-    m_packetno++;
-  }
+  flush_packets();
 
   return FILE_STATUS_MOREDATA;
 }
 
 void
-ac3_packetizer_c::adjust_header_values(ac3_header_t &ac3_header) {
-  if (!m_first_packet)
+ac3_packetizer_c::add_to_buffer(unsigned char *const buf,
+                                int size) {
+  m_parser.add_bytes(buf, size);
+}
+
+void
+ac3_packetizer_c::flush() {
+  m_parser.flush();
+  flush_packets();
+  generic_packetizer_c::flush();
+}
+
+void
+ac3_packetizer_c::flush_packets() {
+  while (m_parser.frame_available()) {
+    ac3::frame_c frame = m_parser.get_frame();
+
+    adjust_header_values(frame);
+
+    int64_t new_timecode = calculate_timecode(frame.m_stream_position);
+    add_packet(new packet_t(frame.m_data, new_timecode, m_single_packet_duration));
+    ++m_packetno;
+  }
+}
+
+int64_t
+ac3_packetizer_c::calculate_timecode(uint64_t stream_position) {
+  auto itr = m_available_timecodes.begin();
+  while (   (itr             != m_available_timecodes.end())
+         && (stream_position >= itr->second))
+    itr++;
+
+  if (m_available_timecodes.begin() == itr)
+    return m_packetno * m_s2tc;
+
+  int64_t new_timecode = (itr - 1)->first;
+  m_available_timecodes.erase(m_available_timecodes.begin(), itr);
+
+  if (m_last_timecode == new_timecode) {
+    m_num_packets_same_tc++;
+    return new_timecode + m_num_packets_same_tc * m_s2tc;
+  }
+
+  m_last_timecode       = new_timecode;
+  m_num_packets_same_tc = 0;
+
+  return new_timecode;
+}
+
+void
+ac3_packetizer_c::adjust_header_values(ac3::frame_c &ac3_header) {
+  if (0 != m_packetno)
     return;
 
-  m_first_packet = false;
+  m_first_ac3_header = ac3_header;
 
-  memcpy(&m_first_ac3_header, &ac3_header, sizeof(ac3_header_t));
-
-  if (16 == m_first_ac3_header.bsid)
+  if (m_first_ac3_header.is_eac3())
     set_codec_id(MKV_A_EAC3);
 
-  if (1536 != m_first_ac3_header.samples) {
-    m_s2tc.set(1000000000ll * m_first_ac3_header.samples, m_samples_per_sec);
+  if (1536 != m_first_ac3_header.m_samples) {
+    m_s2tc.set(1000000000ll * m_first_ac3_header.m_samples, m_first_ac3_header.m_sample_rate);
     m_single_packet_duration = 1 * m_s2tc;
     set_track_default_duration(m_single_packet_duration);
   }
@@ -180,11 +179,11 @@ connection_result_e
 ac3_packetizer_c::can_connect_to(generic_packetizer_c *src,
                                  std::string &error_message) {
   ac3_packetizer_c *asrc = dynamic_cast<ac3_packetizer_c *>(src);
-  if (NULL == asrc)
+  if (nullptr == asrc)
     return CAN_CONNECT_NO_FORMAT;
 
-  connect_check_a_samplerate(m_samples_per_sec, asrc->m_samples_per_sec);
-  connect_check_a_channels(m_first_ac3_header.channels, asrc->m_first_ac3_header.channels);
+  connect_check_a_samplerate(m_first_ac3_header.m_sample_rate, asrc->m_first_ac3_header.m_sample_rate);
+  connect_check_a_channels(  m_first_ac3_header.m_channels,    asrc->m_first_ac3_header.m_channels);
 
   return CAN_CONNECT_YES;
 }
@@ -203,7 +202,7 @@ ac3_bs_packetizer_c::ac3_bs_packetizer_c(generic_reader_c *p_reader,
 static bool s_warning_printed = false;
 
 void
-ac3_bs_packetizer_c::add_to_buffer(unsigned char *buf,
+ac3_bs_packetizer_c::add_to_buffer(unsigned char *const buf,
                                    int size) {
   if (((size % 2) == 1) && !s_warning_printed) {
     mxwarn(Y("ac3_bs_packetizer::add_to_buffer(): Untested code ('size' is odd). "
@@ -254,7 +253,7 @@ ac3_bs_packetizer_c::add_to_buffer(unsigned char *buf,
 
   m_bsb_present = new_bsb_present;
 
-  m_byte_buffer.add(new_buffer, size_add);
+  m_parser.add_bytes(new_buffer, size_add);
 
   safefree(new_buffer);
 }
