@@ -44,7 +44,7 @@ unsigned char *
 dts_packetizer_c::get_dts_packet(dts_header_t &dtsheader,
                                  bool flushing) {
   if (0 == m_packet_buffer.get_size())
-    return NULL;
+    return nullptr;
 
   const unsigned char *buf = m_packet_buffer.get_buffer();
   int buf_size             = m_packet_buffer.get_size();
@@ -53,7 +53,7 @@ dts_packetizer_c::get_dts_packet(dts_header_t &dtsheader,
   if (0 > pos) {
     if (4 < buf_size)
       m_packet_buffer.remove(buf_size - 4);
-    return NULL;
+    return nullptr;
   }
 
   if (0 < pos) {
@@ -65,7 +65,7 @@ dts_packetizer_c::get_dts_packet(dts_header_t &dtsheader,
   pos = find_dts_header(buf, buf_size, &dtsheader, flushing);
 
   if ((0 > pos) || (static_cast<int>(pos + dtsheader.frame_byte_size) > buf_size))
-    return NULL;
+    return nullptr;
 
   if ((1 < verbose) && (dtsheader != m_previous_header)) {
     mxinfo(Y("DTS header information changed! - New format:\n"));
@@ -126,7 +126,7 @@ dts_packetizer_c::process_available_packets(bool flushing) {
   dts_header_t dtsheader;
   unsigned char *dts_packet;
 
-  while ((dts_packet = get_dts_packet(dtsheader, flushing)) != NULL) {
+  while ((dts_packet = get_dts_packet(dtsheader, flushing)) != nullptr) {
     int64_t new_timecode;
     if (!m_available_timecodes.empty()) {
       m_samples_written = 0;
@@ -152,7 +152,7 @@ connection_result_e
 dts_packetizer_c::can_connect_to(generic_packetizer_c *src,
                                  std::string &error_message) {
   dts_packetizer_c *dsrc = dynamic_cast<dts_packetizer_c *>(src);
-  if (NULL == dsrc)
+  if (nullptr == dsrc)
     return CAN_CONNECT_NO_FORMAT;
 
   connect_check_a_samplerate(m_first_header.core_sampling_frequency, dsrc->m_first_header.core_sampling_frequency);
