@@ -103,11 +103,11 @@ connection_result_e
 kate_packetizer_c::can_connect_to(generic_packetizer_c *src,
                                   std::string &error_message) {
   kate_packetizer_c *psrc = dynamic_cast<kate_packetizer_c *>(src);
-  if (NULL == psrc)
+  if (nullptr == psrc)
     return CAN_CONNECT_NO_FORMAT;
 
-  if (   ((NULL == m_ti.m_private_data) && (NULL != src->m_ti.m_private_data))
-      || ((NULL != m_ti.m_private_data) && (NULL == src->m_ti.m_private_data))
+  if (   ((nullptr == m_ti.m_private_data) && (nullptr != src->m_ti.m_private_data))
+      || ((nullptr != m_ti.m_private_data) && (nullptr == src->m_ti.m_private_data))
       || (m_ti.m_private_size != src->m_ti.m_private_size)) {
     error_message = (boost::format(Y("The codec's private data does not match (lengths: %1% and %2%).")) % m_ti.m_private_size % src->m_ti.m_private_size).str();
     return CAN_CONNECT_MAYBE_CODECPRIVATE;
