@@ -66,7 +66,7 @@ textsubs_packetizer_c::process(packet_cptr packet) {
 
   if (0 > packet->duration) {
     subtitle_number_packet_extension_c *extension = dynamic_cast<subtitle_number_packet_extension_c *>(packet->find_extension(packet_extension_c::SUBTITLE_NUMBER));
-    mxwarn_tid(m_ti.m_fname, m_ti.m_id, boost::format(Y("Ignoring an entry which starts after it ends (%1%).\n")) % (NULL != extension ? extension->get_number() : static_cast<unsigned int>(m_packetno)));
+    mxwarn_tid(m_ti.m_fname, m_ti.m_id, boost::format(Y("Ignoring an entry which starts after it ends (%1%).\n")) % (nullptr != extension ? extension->get_number() : static_cast<unsigned int>(m_packetno)));
     return FILE_STATUS_MOREDATA;
   }
 
@@ -92,11 +92,11 @@ connection_result_e
 textsubs_packetizer_c::can_connect_to(generic_packetizer_c *src,
                                       std::string &error_message) {
   textsubs_packetizer_c *psrc = dynamic_cast<textsubs_packetizer_c *>(src);
-  if (NULL == psrc)
+  if (nullptr == psrc)
     return CAN_CONNECT_NO_FORMAT;
 
-  if (   ((NULL == m_ti.m_private_data) && (NULL != src->m_ti.m_private_data))
-      || ((NULL != m_ti.m_private_data) && (NULL == src->m_ti.m_private_data))
+  if (   ((nullptr == m_ti.m_private_data) && (nullptr != src->m_ti.m_private_data))
+      || ((nullptr != m_ti.m_private_data) && (nullptr == src->m_ti.m_private_data))
       || (m_ti.m_private_size != src->m_ti.m_private_size)) {
     error_message = (boost::format(Y("The codec's private data does not match (lengths: %1% and %2%).")) % m_ti.m_private_size % src->m_ti.m_private_size).str();
     return CAN_CONNECT_MAYBE_CODECPRIVATE;
