@@ -69,7 +69,7 @@ connection_result_e
 tta_packetizer_c::can_connect_to(generic_packetizer_c *src,
                                  std::string &error_message) {
   tta_packetizer_c *psrc = dynamic_cast<tta_packetizer_c *>(src);
-  if (NULL == psrc)
+  if (nullptr == psrc)
     return CAN_CONNECT_NO_FORMAT;
 
   connect_check_a_samplerate(m_sample_rate,   psrc->m_sample_rate);
