@@ -11,10 +11,7 @@
 #ifndef __PROPEDIT_TARGET_H
 #define __PROPEDIT_TARGET_H
 
-#include "common/os.h"
-
-#include <string>
-#include <vector>
+#include "common/common_pch.h"
 
 #include <ebml/EbmlMaster.h>
 #include <matroska/KaxTags.h>
@@ -81,7 +78,7 @@ public:
   bool has_changes() const;
   bool has_add_or_set_change() const;
 
-  void set_level1_element(ebml_element_cptr level1_element, ebml_element_cptr track_headers = ebml_element_cptr(NULL));
+  void set_level1_element(ebml_element_cptr level1_element, ebml_element_cptr track_headers = ebml_element_cptr(nullptr));
 
   void execute();
 
